@@ -24,6 +24,7 @@ import (
 	"net/url"
 
 	"k8s.io/kops/pkg/pki"
+	"k8s.io/kops/util/pkg/vfs"
 
 	certmanager "github.com/jetstack/cert-manager/pkg/client/clientset/versioned"
 	"k8s.io/apimachinery/pkg/api/errors"
@@ -72,7 +73,7 @@ func (m *AddonMenu) MergeAddons(o *AddonMenu) {
 		if existing == nil {
 			m.Addons[k] = v
 		} else {
-			if v.ChannelVersion().replaces(existing.ChannelVersion()) {
+			if v.ChannelVersion().replaces(k, existing.ChannelVersion()) {
 				m.Addons[k] = v
 			}
 		}
@@ -81,9 +82,10 @@ func (m *AddonMenu) MergeAddons(o *AddonMenu) {
 
 func (a *Addon) ChannelVersion() *ChannelVersion {
 	return &ChannelVersion{
-		Channel:      &a.ChannelName,
-		Id:           a.Spec.Id,
-		ManifestHash: a.Spec.ManifestHash,
+		Channel:          &a.ChannelName,
+		Id:               a.Spec.Id,
+		ManifestHash:     a.Spec.ManifestHash,
+		SystemGeneration: CurrentSystemGeneration,
 	}
 }
 
@@ -119,7 +121,7 @@ func (a *Addon) GetRequiredUpdates(ctx context.Context, k8sClient kubernetes.Int
 		}
 	}
 
-	if existingVersion != nil && !newVersion.replaces(existingVersion) {
+	if existingVersion != nil && !newVersion.replaces(a.Name, existingVersion) {
 		newVersion = nil
 	}
 
@@ -151,7 +153,7 @@ func (a *Addon) GetManifestFullUrl() (*url.URL, error) {
 	return manifestURL, nil
 }
 
-func (a *Addon) EnsureUpdated(ctx context.Context, k8sClient kubernetes.Interface, cmClient certmanager.Interface) (*AddonUpdate, error) {
+func (a *Addon) EnsureUpdated(ctx context.Context, k8sClient kubernetes.Interface, cmClient certmanager.Interface, pruner *Pruner) (*AddonUpdate, error) {
 	required, err := a.GetRequiredUpdates(ctx, k8sClient, cmClient)
 	if err != nil {
 		return nil, err
@@ -167,9 +169,18 @@ func (a *Addon) EnsureUpdated(ctx context.Context, k8sClient kubernetes.Interfac
 		}
 		klog.Infof("Applying update from %q", manifestURL)
 
-		err = Apply(manifestURL.String())
+		// We copy the manifest to a temp file because it is likely e.g. an s3 URL, which kubectl can't read
+		data, err := vfs.Context.ReadFile(manifestURL.String())
 		if err != nil {
-			return nil, fmt.Errorf("error applying update from %q: %v", manifestURL, err)
+			return nil, fmt.Errorf("error reading manifest: %w", err)
+		}
+
+		if err := Apply(data); err != nil {
+			return nil, fmt.Errorf("error applying update from %q: %w", manifestURL, err)
+		}
+
+		if err := pruner.Prune(ctx, data, a.Spec.Prune); err != nil {
+			return nil, fmt.Errorf("error pruning manifest from %q: %w", manifestURL, err)
 		}
 
 		if err := a.AddNeedsUpdateLabel(ctx, k8sClient, required); err != nil {
