@@ -66,6 +66,16 @@ func RunApplyChannel(ctx context.Context, f Factory, out io.Writer, options *App
 		return err
 	}
 
+	dynamicClient, err := f.DynamicClient()
+	if err != nil {
+		return err
+	}
+
+	restMapper, err := f.RESTMapper()
+	if err != nil {
+		return err
+	}
+
 	kubernetesVersionInfo, err := k8sClient.Discovery().ServerVersion()
 	if err != nil {
 		return fmt.Errorf("error querying kubernetes version: %v", err)
@@ -200,8 +210,13 @@ func RunApplyChannel(ctx context.Context, f Factory, out io.Writer, options *App
 		return nil
 	}
 
+	pruner := &channels.Pruner{
+		Client:     dynamicClient,
+		RESTMapper: restMapper,
+	}
+
 	for _, needUpdate := range needUpdates {
-		update, err := needUpdate.EnsureUpdated(ctx, k8sClient, cmClient)
+		update, err := needUpdate.EnsureUpdated(ctx, k8sClient, cmClient, pruner)
 		if err != nil {
 			fmt.Printf("error updating %q: %v", needUpdate.Name, err)
 		} else if update != nil {
