@@ -19,9 +19,11 @@ package cmd
 import (
 	"fmt"
 
+	"k8s.io/cli-runtime/pkg/genericclioptions"
+	"k8s.io/client-go/dynamic"
 	"k8s.io/client-go/kubernetes"
 	"k8s.io/client-go/rest"
-	"k8s.io/client-go/tools/clientcmd"
+	"k8s.io/client-go/restmapper"
 
 	_ "k8s.io/client-go/plugin/pkg/client/auth"
 
@@ -31,36 +33,43 @@ import (
 type Factory interface {
 	KubernetesClient() (kubernetes.Interface, error)
 	CertManagerClient() (certmanager.Interface, error)
+	RESTMapper() (*restmapper.DeferredDiscoveryRESTMapper, error)
+	DynamicClient() (dynamic.Interface, error)
 }
 
 type DefaultFactory struct {
+	ConfigFlags genericclioptions.ConfigFlags
+
 	kubernetesClient  kubernetes.Interface
 	certManagerClient certmanager.Interface
+
+	cachedRESTConfig *rest.Config
+	dynamicClient    dynamic.Interface
+	restMapper       *restmapper.DeferredDiscoveryRESTMapper
 }
 
 var _ Factory = &DefaultFactory{}
 
-func loadConfig() (*rest.Config, error) {
-	loadingRules := clientcmd.NewDefaultClientConfigLoadingRules()
-	loadingRules.DefaultClientConfig = &clientcmd.DefaultClientConfig
-
-	configOverrides := &clientcmd.ConfigOverrides{
-		ClusterDefaults: clientcmd.ClusterDefaults,
+func (f *DefaultFactory) restConfig() (*rest.Config, error) {
+	if f.cachedRESTConfig == nil {
+		restConfig, err := f.ConfigFlags.ToRESTConfig()
+		if err != nil {
+			return nil, fmt.Errorf("cannot load kubecfg settings: %w", err)
+		}
+		f.cachedRESTConfig = restConfig
 	}
-
-	kubeConfig := clientcmd.NewNonInteractiveDeferredLoadingClientConfig(loadingRules, configOverrides)
-	return kubeConfig.ClientConfig()
+	return f.cachedRESTConfig, nil
 }
 
 func (f *DefaultFactory) KubernetesClient() (kubernetes.Interface, error) {
 	if f.kubernetesClient == nil {
-		config, err := loadConfig()
+		restConfig, err := f.restConfig()
 		if err != nil {
-			return nil, fmt.Errorf("cannot load kubecfg settings: %v", err)
+			return nil, err
 		}
-		k8sClient, err := kubernetes.NewForConfig(config)
+		k8sClient, err := kubernetes.NewForConfig(restConfig)
 		if err != nil {
-			return nil, fmt.Errorf("cannot build kube client: %v", err)
+			return nil, fmt.Errorf("cannot build kube client: %w", err)
 		}
 		f.kubernetesClient = k8sClient
 	}
@@ -68,13 +77,29 @@ func (f *DefaultFactory) KubernetesClient() (kubernetes.Interface, error) {
 	return f.kubernetesClient, nil
 }
 
+func (f *DefaultFactory) DynamicClient() (dynamic.Interface, error) {
+	if f.dynamicClient == nil {
+		restConfig, err := f.restConfig()
+		if err != nil {
+			return nil, fmt.Errorf("cannot load kubecfg settings: %w", err)
+		}
+		dynamicClient, err := dynamic.NewForConfig(restConfig)
+		if err != nil {
+			return nil, fmt.Errorf("cannot build dynamicClient client: %v", err)
+		}
+		f.dynamicClient = dynamicClient
+	}
+
+	return f.dynamicClient, nil
+}
+
 func (f *DefaultFactory) CertManagerClient() (certmanager.Interface, error) {
 	if f.certManagerClient == nil {
-		config, err := loadConfig()
+		restConfig, err := f.restConfig()
 		if err != nil {
-			return nil, fmt.Errorf("cannot load kubecfg settings: %v", err)
+			return nil, err
 		}
-		certManagerClient, err := certmanager.NewForConfig(config)
+		certManagerClient, err := certmanager.NewForConfig(restConfig)
 		if err != nil {
 			return nil, fmt.Errorf("cannot build kube client: %v", err)
 		}
@@ -83,3 +108,18 @@ func (f *DefaultFactory) CertManagerClient() (certmanager.Interface, error) {
 
 	return f.certManagerClient, nil
 }
+
+func (f *DefaultFactory) RESTMapper() (*restmapper.DeferredDiscoveryRESTMapper, error) {
+	if f.restMapper == nil {
+		discoveryClient, err := f.ConfigFlags.ToDiscoveryClient()
+		if err != nil {
+			return nil, err
+		}
+
+		restMapper := restmapper.NewDeferredDiscoveryRESTMapper(discoveryClient)
+
+		f.restMapper = restMapper
+	}
+
+	return f.restMapper, nil
+}
