@@ -27,7 +27,6 @@ import (
 	"encoding/pem"
 	"fmt"
 	"io"
-	"io/ioutil"
 	"os"
 	"path"
 	"reflect"
@@ -136,6 +135,16 @@ func (i *integrationTest) withCiliumEtcd() *integrationTest {
 	return i
 }
 
+func (i *integrationTest) withDedicatedAPIServer() *integrationTest {
+	i.expectTerraformFilenames = append(i.expectTerraformFilenames,
+		"aws_iam_role_apiservers."+i.clusterName+"_policy",
+		"aws_iam_role_policy_apiservers."+i.clusterName+"_policy",
+		"aws_launch_template_apiserver.apiservers."+i.clusterName+"_user_data",
+		"aws_s3_bucket_object_nodeupconfig-apiserver_content",
+	)
+	return i
+}
+
 func (i *integrationTest) withNTH() *integrationTest {
 	i.nth = true
 	return i
@@ -167,7 +176,13 @@ func (i *integrationTest) withAddons(addons ...string) *integrationTest {
 	return i
 }
 
-const dnsControllerAddon = "dns-controller.addons.k8s.io-k8s-1.12"
+const (
+	dnsControllerAddon  = "dns-controller.addons.k8s.io-k8s-1.12"
+	awsCCMAddon         = "aws-cloud-controller.addons.k8s.io-k8s-1.18"
+	awsEBSCSIAddon      = "aws-ebs-csi-driver.addons.k8s.io-k8s-1.17"
+	leaderElectionAddon = "leader-migration.rbac.addons.k8s.io-k8s-1.23"
+	certManagerAddon    = "certmanager.io-k8s-1.16"
+)
 
 // TestMinimal runs the test on a minimum configuration, similar to kops create cluster minimal.example.com --zones us-west-1a
 func TestMinimal(t *testing.T) {
@@ -177,6 +192,18 @@ func TestMinimal(t *testing.T) {
 	newIntegrationTest("minimal.example.com", "minimal").runTestCloudformation(t)
 }
 
+// TestMinimal runs the test on a minimum configuration
+func TestMinimal_v1_23(t *testing.T) {
+	newIntegrationTest("minimal.example.com", "minimal-1.23").
+		withAddons(
+			awsEBSCSIAddon,
+			dnsControllerAddon,
+			"leader-migration.rbac.addons.k8s.io-k8s-1.23",
+		).
+		runTestTerraformAWS(t)
+	newIntegrationTest("minimal.example.com", "minimal").runTestCloudformation(t)
+}
+
 func TestNvidia(t *testing.T) {
 	newIntegrationTest("minimal.example.com", "nvidia").
 		withAddons(
@@ -184,6 +211,7 @@ func TestNvidia(t *testing.T) {
 			"nvidia.addons.k8s.io-k8s-1.16",
 		).
 		runTestTerraformAWS(t)
+	newIntegrationTest("minimal.example.com", "nvidia").runTestCloudformation(t)
 }
 
 // TestMinimal runs the test on a minimum gossip configuration
@@ -193,17 +221,25 @@ func TestMinimalGossip(t *testing.T) {
 		runTestTerraformAWS(t)
 }
 
+// TestMinimal runs the test on a minimum gossip configuration with irsa enabled
+func TestMinimalGossipIRSA(t *testing.T) {
+	newIntegrationTest("minimal.k8s.local", "minimal_gossip_irsa").
+		withOIDCDiscovery().
+		withAddons(dnsControllerAddon).
+		runTestTerraformAWS(t)
+}
+
 // TestMinimalGCE runs tests on a minimal GCE configuration
 func TestMinimalGCE(t *testing.T) {
 	newIntegrationTest("minimal-gce.example.com", "minimal_gce").
-		withAddons(dnsControllerAddon).
+		withAddons(dnsControllerAddon, leaderElectionAddon, "gcp-pd-csi-driver.addons.k8s.io-k8s-1.23").
 		runTestTerraformGCE(t)
 }
 
 // TestMinimalGCE runs tests on a minimal GCE configuration with private topology.
 func TestMinimalGCEPrivate(t *testing.T) {
 	newIntegrationTest("minimal-gce-private.example.com", "minimal_gce_private").
-		withAddons(dnsControllerAddon).
+		withAddons(dnsControllerAddon, "rbac.addons.k8s.io-k8s-1.8").
 		runTestTerraformGCE(t)
 }
 
@@ -218,7 +254,7 @@ func TestHA(t *testing.T) {
 // --zones us-test1-a,us-test1-b,us-test1-c --master-count=3
 func TestHighAvailabilityGCE(t *testing.T) {
 	newIntegrationTest("ha-gce.example.com", "ha_gce").withZones(3).
-		withAddons(dnsControllerAddon).
+		withAddons(dnsControllerAddon, "rbac.addons.k8s.io-k8s-1.8").
 		runTestTerraformGCE(t)
 }
 
@@ -247,14 +283,47 @@ func TestExternalPolicies(t *testing.T) {
 		runTestTerraformAWS(t)
 }
 
-// TestMinimalIPv6 runs the test on a minimum IPv6 configuration, similar to kops create cluster minimal.example.com --zones us-west-1a
+// TestMinimalIPv6 runs the test on a minimum IPv6 configuration
 func TestMinimalIPv6(t *testing.T) {
 	newIntegrationTest("minimal-ipv6.example.com", "minimal-ipv6").
-		withAddons(dnsControllerAddon).
+		withAddons(awsCCMAddon, awsEBSCSIAddon, dnsControllerAddon).
 		runTestTerraformAWS(t)
 	newIntegrationTest("minimal-ipv6.example.com", "minimal-ipv6").runTestCloudformation(t)
 }
 
+// TestMinimalIPv6 runs the test on a minimum IPv6 configuration
+func TestMinimalIPv6Private(t *testing.T) {
+	newIntegrationTest("minimal-ipv6.example.com", "minimal-ipv6-private").
+		withAddons(awsCCMAddon, awsEBSCSIAddon, dnsControllerAddon).
+		runTestTerraformAWS(t)
+}
+
+// TestMinimalIPv6Calico runs the test on a minimum IPv6 configuration with Calico
+func TestMinimalIPv6Calico(t *testing.T) {
+	featureflag.ParseFlags("+AWSIPv6")
+	unsetFeatureFlags := func() {
+		featureflag.ParseFlags("-AWSIPv6")
+	}
+	defer unsetFeatureFlags()
+	newIntegrationTest("minimal-ipv6.example.com", "minimal-ipv6-calico").
+		withAddons(awsCCMAddon, awsEBSCSIAddon, calicoAddon, dnsControllerAddon).
+		runTestTerraformAWS(t)
+	newIntegrationTest("minimal-ipv6.example.com", "minimal-ipv6-calico").runTestCloudformation(t)
+}
+
+// TestMinimalIPv6Calico runs the test on a minimum IPv6 configuration with Cilium
+func TestMinimalIPv6Cilium(t *testing.T) {
+	featureflag.ParseFlags("+AWSIPv6")
+	unsetFeatureFlags := func() {
+		featureflag.ParseFlags("-AWSIPv6")
+	}
+	defer unsetFeatureFlags()
+	newIntegrationTest("minimal-ipv6.example.com", "minimal-ipv6-cilium").
+		withAddons(awsCCMAddon, awsEBSCSIAddon, ciliumAddon, dnsControllerAddon).
+		runTestTerraformAWS(t)
+	newIntegrationTest("minimal-ipv6.example.com", "minimal-ipv6-cilium").runTestCloudformation(t)
+}
+
 // TestMinimalWarmPool runs the test on a minimum Warm Pool configuration
 func TestMinimalWarmPool(t *testing.T) {
 	newIntegrationTest("minimal-warmpool.example.com", "minimal-warmpool").
@@ -314,11 +383,13 @@ func TestPrivateFlannel(t *testing.T) {
 		runTestTerraformAWS(t)
 }
 
+const calicoAddon = "networking.projectcalico.org-k8s-1.16"
+
 // TestPrivateCalico runs the test on a configuration with private topology, calico networking
 func TestPrivateCalico(t *testing.T) {
 	newIntegrationTest("privatecalico.example.com", "privatecalico").
 		withPrivate().
-		withAddons("networking.projectcalico.org-k8s-1.16", dnsControllerAddon).
+		withAddons(calicoAddon, dnsControllerAddon).
 		runTestTerraformAWS(t)
 	newIntegrationTest("privatecalico.example.com", "privatecalico").
 		withPrivate().
@@ -507,6 +578,7 @@ func TestExternalDNS(t *testing.T) {
 	newIntegrationTest("minimal.example.com", "external_dns").
 		withAddons("external-dns.addons.k8s.io-k8s-1.19").
 		runTestTerraformAWS(t)
+	newIntegrationTest("minimal.example.com", "external_dns").runTestCloudformation(t)
 }
 
 func TestExternalDNSIRSA(t *testing.T) {
@@ -621,6 +693,10 @@ func TestAPIServerNodes(t *testing.T) {
 
 	newIntegrationTest("minimal.example.com", "apiservernodes").
 		runTestCloudformation(t)
+	newIntegrationTest("minimal.example.com", "apiservernodes").
+		withAddons(dnsControllerAddon, awsEBSCSIAddon).
+		withDedicatedAPIServer().
+		runTestTerraformAWS(t)
 }
 
 // TestNTHQueueProcessor tests the output for resources required by NTH Queue Processor mode
@@ -641,6 +717,8 @@ func TestCustomIRSA(t *testing.T) {
 		withServiceAccountRole("myserviceaccount.test-wildcard", false).
 		withServiceAccountRole("myotherserviceaccount.myapp", true).
 		withAddons(dnsControllerAddon).
+		withAddons(certManagerAddon).
+		withAddons("eks-pod-identity-webhook.addons.k8s.io-k8s-1.16").
 		runTestTerraformAWS(t)
 }
 
@@ -709,7 +787,7 @@ func (i *integrationTest) runTest(t *testing.T, h *testutils.IntegrationTestHarn
 
 	// Compare main files
 	{
-		files, err := ioutil.ReadDir(path.Join(h.TempDir, "out"))
+		files, err := os.ReadDir(path.Join(h.TempDir, "out"))
 		if err != nil {
 			t.Fatalf("failed to read dir: %v", err)
 		}
@@ -731,7 +809,7 @@ func (i *integrationTest) runTest(t *testing.T, h *testutils.IntegrationTestHarn
 			t.Fatalf("unexpected files.  actual=%q, expected=%q, test=%q", actualFilenames, expectedFilenames, testDataTFPath)
 		}
 
-		actualTF, err := ioutil.ReadFile(path.Join(h.TempDir, "out", actualTFPath))
+		actualTF, err := os.ReadFile(path.Join(h.TempDir, "out", actualTFPath))
 		if err != nil {
 			t.Fatalf("unexpected error reading actual terraform output: %v", err)
 		}
@@ -742,7 +820,7 @@ func (i *integrationTest) runTest(t *testing.T, h *testutils.IntegrationTestHarn
 	// Compare data files if they are provided
 	if len(expectedDataFilenames) > 0 {
 		actualDataPath := path.Join(h.TempDir, "out", "data")
-		files, err := ioutil.ReadDir(actualDataPath)
+		files, err := os.ReadDir(actualDataPath)
 		if err != nil {
 			t.Fatalf("failed to read data dir: %v", err)
 		}
@@ -773,13 +851,28 @@ func (i *integrationTest) runTest(t *testing.T, h *testutils.IntegrationTestHarn
 		expectedDataPath := path.Join(i.srcDir, "data")
 		{
 			for _, dataFileName := range expectedDataFilenames {
-				actualDataContent, err := ioutil.ReadFile(path.Join(actualDataPath, dataFileName))
+				actualDataContent, err := os.ReadFile(path.Join(actualDataPath, dataFileName))
 				if err != nil {
 					t.Fatalf("failed to read actual data file: %v", err)
 				}
 				golden.AssertMatchesFile(t, string(actualDataContent), path.Join(expectedDataPath, dataFileName))
 			}
 		}
+
+		existingExpectedFiles, err := os.ReadDir(expectedDataPath)
+		if err != nil {
+			t.Fatalf("failed to read data dir: %v", err)
+		}
+		existingExpectedFilenames := make([]string, len(existingExpectedFiles))
+		for i, f := range existingExpectedFiles {
+			existingExpectedFilenames[i] = f.Name()
+		}
+		for j := 0; j < len(existingExpectedFilenames) && j < len(expectedDataFilenames); j++ {
+			if existingExpectedFilenames[j] != expectedDataFilenames[j] {
+				t.Errorf("diff with source directory @%d: %q vs %q", j, existingExpectedFilenames[j], expectedDataFilenames[j])
+				break
+			}
+		}
 	}
 }
 
@@ -1111,7 +1204,6 @@ func (i *integrationTest) runTestTerraformGCE(t *testing.T) {
 		"aws_s3_bucket_object_"+i.clusterName+"-addons-kubelet-api.rbac.addons.k8s.io-k8s-1.9_content",
 		"aws_s3_bucket_object_"+i.clusterName+"-addons-limit-range.addons.k8s.io_content",
 		"aws_s3_bucket_object_"+i.clusterName+"-addons-metadata-proxy.addons.k8s.io-v0.1.12_content",
-		"aws_s3_bucket_object_"+i.clusterName+"-addons-rbac.addons.k8s.io-k8s-1.8_content",
 		"aws_s3_bucket_object_"+i.clusterName+"-addons-storage-gce.addons.k8s.io-v1.7.0_content")
 
 	for j := 0; j < i.zones; j++ {
@@ -1163,7 +1255,7 @@ func (i *integrationTest) runTestCloudformation(t *testing.T) {
 
 	// Compare main files
 	{
-		files, err := ioutil.ReadDir(path.Join(h.TempDir, "out"))
+		files, err := os.ReadDir(path.Join(h.TempDir, "out"))
 		if err != nil {
 			t.Fatalf("failed to read dir: %v", err)
 		}
@@ -1181,7 +1273,7 @@ func (i *integrationTest) runTestCloudformation(t *testing.T) {
 		}
 
 		actualPath := path.Join(h.TempDir, "out", "kubernetes.json")
-		actualCF, err := ioutil.ReadFile(actualPath)
+		actualCF, err := os.ReadFile(actualPath)
 		if err != nil {
 			t.Fatalf("unexpected error reading actual cloudformation output: %v", err)
 		}
@@ -1256,7 +1348,7 @@ func MakeSSHKeyPair(publicKeyPath string, privateKeyPath string) error {
 	if err := pem.Encode(&privateKeyBytes, privateKeyPEM); err != nil {
 		return err
 	}
-	if err := ioutil.WriteFile(privateKeyPath, privateKeyBytes.Bytes(), os.FileMode(0o700)); err != nil {
+	if err := os.WriteFile(privateKeyPath, privateKeyBytes.Bytes(), os.FileMode(0o700)); err != nil {
 		return err
 	}
 
@@ -1265,7 +1357,7 @@ func MakeSSHKeyPair(publicKeyPath string, privateKeyPath string) error {
 		return err
 	}
 	publicKeyBytes := ssh.MarshalAuthorizedKey(publicKey)
-	if err := ioutil.WriteFile(publicKeyPath, publicKeyBytes, os.FileMode(0o744)); err != nil {
+	if err := os.WriteFile(publicKeyPath, publicKeyBytes, os.FileMode(0o744)); err != nil {
 		return err
 	}
 
