@@ -332,7 +332,7 @@ func RunToolboxInstanceSelector(ctx context.Context, f *util.Factory, out io.Wri
 					return fmt.Errorf("error writing cluster yaml to stdout: %v", err)
 				}
 			case OutputJSON:
-				if err := fullOutputJSON(out, ig); err != nil {
+				if err := fullOutputJSON(out, true, ig); err != nil {
 					return fmt.Errorf("error writing cluster json to stdout: %v", err)
 				}
 			default:
