@@ -21,7 +21,6 @@ import (
 	"fmt"
 	"io"
 	"os"
-	"strings"
 
 	"github.com/blang/semver/v4"
 	"github.com/spf13/cobra"
@@ -34,7 +33,6 @@ import (
 	"k8s.io/kops/pkg/commands"
 	"k8s.io/kops/pkg/commands/commandutils"
 	"k8s.io/kops/pkg/pretty"
-	"k8s.io/kops/upup/pkg/fi"
 	"k8s.io/kops/upup/pkg/fi/cloudup"
 	"k8s.io/kops/util/pkg/tables"
 	"k8s.io/kubectl/pkg/util/i18n"
@@ -141,12 +139,6 @@ func RunUpgradeCluster(ctx context.Context, f *util.Factory, out io.Writer, opti
 		return fmt.Errorf("error loading channel %q: %v", channelLocation, err)
 	}
 
-	channelClusterSpec := channel.Spec.Cluster
-	if channelClusterSpec == nil {
-		// Just to prevent too much nil handling
-		channelClusterSpec = &kopsapi.ClusterSpec{}
-	}
-
 	var currentKubernetesVersion *semver.Version
 	{
 		sv, err := kopsutil.ParseKubernetesVersion(cluster.Spec.KubernetesVersion)
@@ -191,14 +183,9 @@ func RunUpgradeCluster(ctx context.Context, f *util.Factory, out io.Writer, opti
 	// Prompt to upgrade image
 	if proposedKubernetesVersion != nil {
 		for _, ig := range instanceGroups {
-			// Before kops v1.23, Spotinst uses the "ig.Spec.MachineType" field as a comma separated list to determine (among other) the allowed spot types.
-			// A list is allowed only if all the items are with the same arch.
-			// Therefore, it should be enough to check the arch for the first (possibly only) item
-			machineType := strings.Split(ig.Spec.MachineType, ",")[0]
-
-			architecture, err := cloudup.MachineArchitecture(cloud, machineType)
+			architecture, err := cloudup.MachineArchitecture(cloud, ig.Spec.MachineType)
 			if err != nil {
-				klog.Warningf("Error finding architecture for machine type %q: %v", machineType, err)
+				klog.Warningf("Error finding architecture for machine type %q: %v", ig.Spec.MachineType, err)
 				continue
 			}
 			image := channel.FindImage(cloud.ProviderID(), *proposedKubernetesVersion, architecture)
@@ -225,28 +212,6 @@ func RunUpgradeCluster(ctx context.Context, f *util.Factory, out io.Writer, opti
 		}
 	}
 
-	// Prompt to upgrade to overlayfs
-	if channelClusterSpec.Docker != nil {
-		if cluster.Spec.Docker == nil {
-			cluster.Spec.Docker = &kopsapi.DockerConfig{}
-		}
-		// TODO: make less hard-coded
-		if channelClusterSpec.Docker.Storage != nil {
-			dockerStorage := fi.StringValue(cluster.Spec.Docker.Storage)
-			if dockerStorage != fi.StringValue(channelClusterSpec.Docker.Storage) {
-				actions = append(actions, &upgradeAction{
-					Item:     "Cluster",
-					Property: "Docker.Storage",
-					Old:      dockerStorage,
-					New:      fi.StringValue(channelClusterSpec.Docker.Storage),
-					apply: func() {
-						cluster.Spec.Docker.Storage = channelClusterSpec.Docker.Storage
-					},
-				})
-			}
-		}
-	}
-
 	if len(actions) == 0 {
 		// TODO: Allow --force option to force even if not needed?
 		// Note stderr - we try not to print to stdout if no update is needed
