@@ -108,10 +108,8 @@ func (b *KubeSchedulerBuilder) Build(c *fi.ModelBuilderContext) error {
 			config = NewSchedulerConfig("kubescheduler.config.k8s.io/v1beta2")
 		} else if b.IsKubernetesGTE("1.19") {
 			config = NewSchedulerConfig("kubescheduler.config.k8s.io/v1beta1")
-		} else if b.IsKubernetesGTE("1.18") {
-			config = NewSchedulerConfig("kubescheduler.config.k8s.io/v1alpha2")
 		} else {
-			config = NewSchedulerConfig("kubescheduler.config.k8s.io/v1alpha1")
+			config = NewSchedulerConfig("kubescheduler.config.k8s.io/v1alpha2")
 		}
 
 		manifest, err := configbuilder.BuildConfigYaml(&kubeScheduler, config)
@@ -196,7 +194,7 @@ func (b *KubeSchedulerBuilder) buildPod(kubeScheduler *kops.KubeSchedulerConfig)
 		flags = append(flags, "--"+flag+"kubeconfig="+defaultKubeConfig)
 	}
 
-	if kubeScheduler.UsePolicyConfigMap != nil {
+	if fi.BoolValue(kubeScheduler.UsePolicyConfigMap) {
 		flags = append(flags, "--policy-configmap=scheduler-policy", "--policy-configmap-namespace=kube-system")
 	}
 
@@ -222,18 +220,22 @@ func (b *KubeSchedulerBuilder) buildPod(kubeScheduler *kops.KubeSchedulerConfig)
 		image = strings.Replace(image, "-amd64", "-"+string(b.Architecture), 1)
 	}
 
+	healthAction := &v1.HTTPGetAction{
+		Host: "127.0.0.1",
+		Path: "/healthz",
+		Port: intstr.FromInt(10251),
+	}
+	if b.IsKubernetesGTE("1.23") {
+		healthAction.Port = intstr.FromInt(10259)
+		healthAction.Scheme = v1.URISchemeHTTPS
+	}
+
 	container := &v1.Container{
 		Name:  "kube-scheduler",
 		Image: image,
 		Env:   proxy.GetProxyEnvVars(b.Cluster.Spec.EgressProxy),
 		LivenessProbe: &v1.Probe{
-			Handler: v1.Handler{
-				HTTPGet: &v1.HTTPGetAction{
-					Host: "127.0.0.1",
-					Path: "/healthz",
-					Port: intstr.FromInt(10251),
-				},
-			},
+			ProbeHandler:        v1.ProbeHandler{HTTPGet: healthAction},
 			InitialDelaySeconds: 15,
 			TimeoutSeconds:      15,
 		},
@@ -250,12 +252,22 @@ func (b *KubeSchedulerBuilder) buildPod(kubeScheduler *kops.KubeSchedulerConfig)
 	addHostPathMapping(pod, container, "logfile", "/var/log/kube-scheduler.log").ReadOnly = false
 	// We use lighter containers that don't include shells
 	// But they have richer logging support via klog
-	container.Command = []string{"/usr/local/bin/kube-scheduler"}
-	container.Args = append(
-		sortedStrings(flags),
-		"--logtostderr=false", // https://github.com/kubernetes/klog/issues/60
-		"--alsologtostderr",
-		"--log-file=/var/log/kube-scheduler.log")
+	if b.IsKubernetesGTE("1.23") {
+		container.Command = []string{"/go-runner"}
+		container.Args = []string{
+			"--log-file=/var/log/kube-scheduler.log",
+			"--also-stdout",
+			"/usr/local/bin/kube-scheduler",
+		}
+		container.Args = append(container.Args, sortedStrings(flags)...)
+	} else {
+		container.Command = []string{"/usr/local/bin/kube-scheduler"}
+		container.Args = append(
+			sortedStrings(flags),
+			"--logtostderr=false", // https://github.com/kubernetes/klog/issues/60
+			"--alsologtostderr",
+			"--log-file=/var/log/kube-scheduler.log")
+	}
 
 	if kubeScheduler.MaxPersistentVolumes != nil {
 		maxPDV := v1.EnvVar{
