@@ -159,6 +159,8 @@ type KubeletConfigSpec struct {
 	Taints []string `json:"taints,omitempty" flag:"register-with-taints"`
 	// FeatureGates is set of key=value pairs that describe feature gates for alpha/experimental features.
 	FeatureGates map[string]string `json:"featureGates,omitempty" flag:"feature-gates"`
+	// Integrate with the kernel memcg notification to determine if memory eviction thresholds are crossed rather than polling.
+	KernelMemcgNotification *bool `json:"kernelMemcgNotification,omitempty" flag:"kernel-memcg-notification"`
 	// Resource reservation for kubernetes system daemons like the kubelet, container runtime, node problem detector, etc.
 	KubeReserved map[string]string `json:"kubeReserved,omitempty" flag:"kube-reserved"`
 	// Control group for kube daemons.
@@ -223,24 +225,30 @@ type KubeletConfigSpec struct {
 	EnableCadvisorJsonEndpoints *bool `json:"enableCadvisorJsonEndpoints,omitempty" flag:"enable-cadvisor-json-endpoints"`
 	// PodPidsLimit is the maximum number of pids in any pod.
 	PodPidsLimit *int64 `json:"podPidsLimit,omitempty" flag:"pod-max-pids"`
+
+	// ShutdownGracePeriod specifies the total duration that the node should delay the shutdown by.
+	// Default: 30s
+	ShutdownGracePeriod *metav1.Duration `json:"shutdownGracePeriod,omitempty"`
+	// ShutdownGracePeriodCriticalPods specifies the duration used to terminate critical pods during a node shutdown.
+	// Default: 10s
+	ShutdownGracePeriodCriticalPods *metav1.Duration `json:"shutdownGracePeriodCriticalPods,omitempty"`
 }
 
 // KubeProxyConfig defines the configuration for a proxy
 type KubeProxyConfig struct {
 	Image string `json:"image,omitempty"`
-	// TODO: Better type ?
 	// CPURequest, cpu request compute resource for kube proxy e.g. "20m"
-	CPURequest string `json:"cpuRequest,omitempty"`
+	CPURequest *resource.Quantity `json:"cpuRequest,omitempty"`
 	// CPULimit, cpu limit compute resource for kube proxy e.g. "30m"
-	CPULimit string `json:"cpuLimit,omitempty"`
+	CPULimit *resource.Quantity `json:"cpuLimit,omitempty"`
 	// MemoryRequest, memory request compute resource for kube proxy e.g. "30Mi"
-	MemoryRequest string `json:"memoryRequest,omitempty"`
+	MemoryRequest *resource.Quantity `json:"memoryRequest,omitempty"`
 	// MemoryLimit, memory limit compute resource for kube proxy e.g. "30Mi"
-	MemoryLimit string `json:"memoryLimit,omitempty"`
+	MemoryLimit *resource.Quantity `json:"memoryLimit,omitempty"`
 	// LogLevel is the logging level of the proxy
 	LogLevel int32 `json:"logLevel,omitempty" flag:"v"`
 	// ClusterCIDR is the CIDR range of the pods in the cluster
-	ClusterCIDR string `json:"clusterCIDR,omitempty" flag:"cluster-cidr"`
+	ClusterCIDR *string `json:"clusterCIDR,omitempty" flag:"cluster-cidr"`
 	// HostnameOverride, if non-empty, will be used as the identity instead of the actual hostname.
 	HostnameOverride string `json:"hostnameOverride,omitempty" flag:"hostname-override"`
 	// BindAddress is IP address for the proxy server to serve on
@@ -253,8 +261,8 @@ type KubeProxyConfig struct {
 	Enabled *bool `json:"enabled,omitempty"`
 	// Which proxy mode to use: (userspace, iptables, ipvs)
 	ProxyMode string `json:"proxyMode,omitempty" flag:"proxy-mode"`
-	// IPVSExcludeCIDRS is comma-separated list of CIDR's which the ipvs proxier should not touch when cleaning up IPVS rules
-	IPVSExcludeCIDRS []string `json:"ipvsExcludeCidrs,omitempty" flag:"ipvs-exclude-cidrs"`
+	// IPVSExcludeCIDRs is comma-separated list of CIDR's which the ipvs proxier should not touch when cleaning up IPVS rules
+	IPVSExcludeCIDRs []string `json:"ipvsExcludeCidrs,omitempty" flag:"ipvs-exclude-cidrs"`
 	// IPVSMinSyncPeriod is the minimum interval of how often the ipvs rules can be refreshed as endpoints and services change (e.g. '5s', '1m', '2h22m')
 	IPVSMinSyncPeriod *metav1.Duration `json:"ipvsMinSyncPeriod,omitempty" flag:"ipvs-min-sync-period"`
 	// IPVSScheduler is the ipvs scheduler type when proxy mode is ipvs
@@ -465,7 +473,7 @@ type KubeAPIServerConfig struct {
 	MinRequestTimeout *int32 `json:"minRequestTimeout,omitempty" flag:"min-request-timeout"`
 
 	// Memory limit for apiserver in MB (used to configure sizes of caches, etc.)
-	TargetRamMb int32 `json:"targetRamMb,omitempty" flag:"target-ram-mb" flag-empty:"0"`
+	TargetRamMB int32 `json:"targetRamMb,omitempty" flag:"target-ram-mb" flag-empty:"0"`
 
 	// File containing PEM-encoded x509 RSA or ECDSA private or public keys, used to verify ServiceAccount tokens.
 	// The specified file can contain multiple keys, and the flag can be specified multiple times with different files.
@@ -490,13 +498,13 @@ type KubeAPIServerConfig struct {
 	APIAudiences []string `json:"apiAudiences,omitempty" flag:"api-audiences"`
 
 	// CPURequest, cpu request compute resource for api server. Defaults to "150m"
-	CPURequest string `json:"cpuRequest,omitempty"`
+	CPURequest *resource.Quantity `json:"cpuRequest,omitempty"`
 	// CPULimit, cpu limit compute resource for api server e.g. "500m"
-	CPULimit string `json:"cpuLimit,omitempty"`
+	CPULimit *resource.Quantity `json:"cpuLimit,omitempty"`
 	// MemoryRequest, memory request compute resource for api server e.g. "30Mi"
-	MemoryRequest string `json:"memoryRequest,omitempty"`
+	MemoryRequest *resource.Quantity `json:"memoryRequest,omitempty"`
 	// MemoryLimit, memory limit compute resource for api server e.g. "30Mi"
-	MemoryLimit string `json:"memoryLimit,omitempty"`
+	MemoryLimit *resource.Quantity `json:"memoryLimit,omitempty"`
 
 	// Amount of time to retain Kubernetes events
 	EventTTL *metav1.Duration `json:"eventTTL,omitempty" flag:"event-ttl"`
@@ -635,7 +643,7 @@ type KubeControllerManagerConfig struct {
 	ConcurrentServiceaccountTokenSyncs *int32 `json:"concurrentServiceaccountTokenSyncs,omitempty" flag:"concurrent-serviceaccount-token-syncs"`
 	// The number of replicationcontroller objects that are allowed to sync concurrently.
 	// This only works on kubernetes >= 1.14
-	ConcurrentRcSyncs *int32 `json:"concurrentRcSyncs,omitempty" flag:"concurrent-rc-syncs"`
+	ConcurrentRCSyncs *int32 `json:"concurrentRcSyncs,omitempty" flag:"concurrent-rc-syncs"`
 	// AuthenticationKubeconfig is the path to an Authentication Kubeconfig
 	AuthenticationKubeconfig string `json:"authenticationKubeconfig,omitempty" flag:"authentication-kubeconfig"`
 	// AuthorizationKubeconfig is the path to an Authorization Kubeconfig
@@ -647,6 +655,8 @@ type KubeControllerManagerConfig struct {
 
 	// EnableProfiling enables profiling via web interface host:port/debug/pprof/
 	EnableProfiling *bool `json:"enableProfiling,omitempty" flag:"profiling"`
+	// EnableLeaderMigration enables controller leader migration.
+	EnableLeaderMigration *bool `json:"enableLeaderMigration,omitempty" flag:"enable-leader-migration"`
 }
 
 // CloudControllerManagerConfig is the configuration of the cloud controller
@@ -674,6 +684,8 @@ type CloudControllerManagerConfig struct {
 	LeaderElection *LeaderElectionConfiguration `json:"leaderElection,omitempty"`
 	// UseServiceAccountCredentials controls whether we use individual service account credentials for each controller.
 	UseServiceAccountCredentials *bool `json:"useServiceAccountCredentials,omitempty" flag:"use-service-account-credentials"`
+	// EnableLeaderMigration enables controller leader migration.
+	EnableLeaderMigration *bool `json:"enableLeaderMigration,omitempty" flag:"enable-leader-migration"`
 }
 
 // KubeSchedulerConfig is the configuration for the kube-scheduler
@@ -695,8 +707,8 @@ type KubeSchedulerConfig struct {
 	// FeatureGates is set of key=value pairs that describe feature gates for alpha/experimental features.
 	FeatureGates map[string]string `json:"featureGates,omitempty" flag:"feature-gates"`
 	// MaxPersistentVolumes changes the maximum number of persistent volumes the scheduler will scheduler onto the same
-	// node. Only takes into affect if value is positive. This corresponds to the KUBE_MAX_PD_VOLS environment variable,
-	// which has been supported as far back as Kubernetes 1.7. The default depends on the version and the cloud provider
+	// node. Only takes effect if value is positive. This corresponds to the KUBE_MAX_PD_VOLS environment variable.
+	// The default depends on the version and the cloud provider
 	// as outlined: https://kubernetes.io/docs/concepts/storage/storage-limits/
 	MaxPersistentVolumes *int32 `json:"maxPersistentVolumes,omitempty"`
 	// Qps sets the maximum qps to send to apiserver after the burst quota is exhausted
@@ -756,6 +768,7 @@ type OpenstackLoadbalancerConfig struct {
 	SubnetID              *string `json:"subnetID,omitempty"`
 	ManageSecGroups       *bool   `json:"manageSecurityGroups,omitempty"`
 	EnableIngressHostname *bool   `json:"enableIngressHostname,omitempty"`
+	IngressHostnameSuffix *string `json:"ingressHostnameSuffix,omitempty"`
 }
 
 type OpenstackBlockStorageConfig struct {
@@ -844,19 +857,26 @@ type CloudConfiguration struct {
 	// AWS cloud-config options
 	DisableSecurityGroupIngress *bool   `json:"disableSecurityGroupIngress,omitempty"`
 	ElbSecurityGroup            *string `json:"elbSecurityGroup,omitempty"`
-	// VSphereUsername is deprecated and will be removed in a later version
+	// VSphereUsername is unused.
+	// +k8s:conversion-gen=false
 	VSphereUsername *string `json:"vSphereUsername,omitempty"`
-	// VSpherePassword is deprecated and will be removed in a later version
+	// VSpherePassword is unused.
+	// +k8s:conversion-gen=false
 	VSpherePassword *string `json:"vSpherePassword,omitempty"`
-	// VSphereServer is deprecated and will be removed in a later version
+	// VSphereServer is unused.
+	// +k8s:conversion-gen=false
 	VSphereServer *string `json:"vSphereServer,omitempty"`
-	// VShpereDatacenter is deprecated and will be removed in a later version
+	// VShpereDatacenter is unused.
+	// +k8s:conversion-gen=false
 	VSphereDatacenter *string `json:"vSphereDatacenter,omitempty"`
-	// VSphereResourcePool is deprecated and will be removed in a later version
+	// VSphereResourcePool is unused.
+	// +k8s:conversion-gen=false
 	VSphereResourcePool *string `json:"vSphereResourcePool,omitempty"`
-	// VSphereDatastore is deprecated and will be removed in a later version
+	// VSphereDatastore is unused.
+	// +k8s:conversion-gen=false
 	VSphereDatastore *string `json:"vSphereDatastore,omitempty"`
-	// VSphereCoreDNSServer is deprecated and will be removed in a later version
+	// VSphereCoreDNSServer is unused.
+	// +k8s:conversion-gen=false
 	VSphereCoreDNSServer *string `json:"vSphereCoreDNSServer,omitempty"`
 	// Spotinst cloud-config specs
 	SpotinstProduct     *string `json:"spotinstProduct,omitempty"`
@@ -867,6 +887,8 @@ type CloudConfiguration struct {
 	Azure *AzureConfiguration `json:"azure,omitempty"`
 	// AWSEBSCSIDriver is the config for the AWS EBS CSI driver
 	AWSEBSCSIDriver *AWSEBSCSIDriver `json:"awsEBSCSIDriver,omitempty"`
+	// GCPPDCSIDriver is the config for the GCP PD CSI driver
+	GCPPDCSIDriver *GCPPDCSIDriver `json:"gcpPDCSIDriver,omitempty"`
 }
 
 // AWSEBSCSIDriver is the config for the AWS EBS CSI driver
@@ -886,6 +908,12 @@ type AWSEBSCSIDriver struct {
 	VolumeAttachLimit *int `json:"volumeAttachLimit,omitempty"`
 }
 
+// GCPPDCSIDriver is the config for the GCP PD CSI driver
+type GCPPDCSIDriver struct {
+	// Enabled enables the GCP PD CSI driver
+	Enabled *bool `json:"enabled,omitempty"`
+}
+
 // SnapshotControllerConfig is the config for the CSI Snapshot Controller
 type SnapshotControllerConfig struct {
 	// Enabled enables the CSI Snapshot Controller
@@ -957,7 +985,9 @@ type ClusterAutoscalerConfig struct {
 	// Default: false
 	Enabled *bool `json:"enabled,omitempty"`
 	// Expander determines the strategy for which instance group gets expanded.
-	// Supported values: least-waste, most-pods, random.
+	// Supported values: least-waste, most-pods, random, price, priority.
+	// The price expander is only supported on GCE.
+	// The priority expander requires additional configuration via a ConfigMap.
 	// Default: least-waste
 	Expander *string `json:"expander,omitempty"`
 	// BalanceSimilarNodeGroups makes cluster autoscaler treat similar node groups as one.
