@@ -443,7 +443,6 @@ func Test_Validate_AdditionalPolicies(t *testing.T) {
 					},
 				},
 			},
-			IAM: &kops.IAMSpec{},
 		}
 		errs := validateClusterSpec(clusterSpec, &kops.Cluster{Spec: *clusterSpec}, field.NewPath("spec"))
 		testErrors(t, g.Input, errs, g.ExpectedErrors)
@@ -451,8 +450,8 @@ func Test_Validate_AdditionalPolicies(t *testing.T) {
 }
 
 type caliInput struct {
-	Calico *kops.CalicoNetworkingSpec
-	Etcd   kops.EtcdClusterSpec
+	Cluster *kops.ClusterSpec
+	Calico  *kops.CalicoNetworkingSpec
 }
 
 func Test_Validate_Calico(t *testing.T) {
@@ -465,7 +464,6 @@ func Test_Validate_Calico(t *testing.T) {
 			Description: "empty specs",
 			Input: caliInput{
 				Calico: &kops.CalicoNetworkingSpec{},
-				Etcd:   kops.EtcdClusterSpec{},
 			},
 		},
 		{
@@ -474,7 +472,6 @@ func Test_Validate_Calico(t *testing.T) {
 				Calico: &kops.CalicoNetworkingSpec{
 					TyphaReplicas: 3,
 				},
-				Etcd: kops.EtcdClusterSpec{},
 			},
 		},
 		{
@@ -483,7 +480,6 @@ func Test_Validate_Calico(t *testing.T) {
 				Calico: &kops.CalicoNetworkingSpec{
 					TyphaReplicas: -1,
 				},
-				Etcd: kops.EtcdClusterSpec{},
 			},
 			ExpectedErrors: []string{"Invalid value::calico.typhaReplicas"},
 		},
@@ -491,9 +487,6 @@ func Test_Validate_Calico(t *testing.T) {
 			Description: "with etcd version",
 			Input: caliInput{
 				Calico: &kops.CalicoNetworkingSpec{},
-				Etcd: kops.EtcdClusterSpec{
-					Version: "3.2.18",
-				},
 			},
 		},
 		{
@@ -502,7 +495,6 @@ func Test_Validate_Calico(t *testing.T) {
 				Calico: &kops.CalicoNetworkingSpec{
 					IPv4AutoDetectionMethod: "first-found",
 				},
-				Etcd: kops.EtcdClusterSpec{},
 			},
 		},
 		{
@@ -511,7 +503,6 @@ func Test_Validate_Calico(t *testing.T) {
 				Calico: &kops.CalicoNetworkingSpec{
 					IPv6AutoDetectionMethod: "first-found",
 				},
-				Etcd: kops.EtcdClusterSpec{},
 			},
 		},
 		{
@@ -520,7 +511,6 @@ func Test_Validate_Calico(t *testing.T) {
 				Calico: &kops.CalicoNetworkingSpec{
 					IPv4AutoDetectionMethod: "can-reach=8.8.8.8",
 				},
-				Etcd: kops.EtcdClusterSpec{},
 			},
 		},
 		{
@@ -529,7 +519,6 @@ func Test_Validate_Calico(t *testing.T) {
 				Calico: &kops.CalicoNetworkingSpec{
 					IPv6AutoDetectionMethod: "can-reach=2001:4860:4860::8888",
 				},
-				Etcd: kops.EtcdClusterSpec{},
 			},
 		},
 		{
@@ -538,7 +527,6 @@ func Test_Validate_Calico(t *testing.T) {
 				Calico: &kops.CalicoNetworkingSpec{
 					IPv4AutoDetectionMethod: "bogus",
 				},
-				Etcd: kops.EtcdClusterSpec{},
 			},
 			ExpectedErrors: []string{"Invalid value::calico.ipv4AutoDetectionMethod"},
 		},
@@ -548,7 +536,6 @@ func Test_Validate_Calico(t *testing.T) {
 				Calico: &kops.CalicoNetworkingSpec{
 					IPv6AutoDetectionMethod: "bogus",
 				},
-				Etcd: kops.EtcdClusterSpec{},
 			},
 			ExpectedErrors: []string{"Invalid value::calico.ipv6AutoDetectionMethod"},
 		},
@@ -558,7 +545,6 @@ func Test_Validate_Calico(t *testing.T) {
 				Calico: &kops.CalicoNetworkingSpec{
 					IPv6AutoDetectionMethod: "interface=",
 				},
-				Etcd: kops.EtcdClusterSpec{},
 			},
 			ExpectedErrors: []string{"Invalid value::calico.ipv6AutoDetectionMethod"},
 		},
@@ -568,7 +554,6 @@ func Test_Validate_Calico(t *testing.T) {
 				Calico: &kops.CalicoNetworkingSpec{
 					IPv4AutoDetectionMethod: "interface=en.*,eth0",
 				},
-				Etcd: kops.EtcdClusterSpec{},
 			},
 		},
 		{
@@ -577,7 +562,6 @@ func Test_Validate_Calico(t *testing.T) {
 				Calico: &kops.CalicoNetworkingSpec{
 					IPv6AutoDetectionMethod: "skip-interface=en.*,eth0",
 				},
-				Etcd: kops.EtcdClusterSpec{},
 			},
 		},
 		{
@@ -586,7 +570,6 @@ func Test_Validate_Calico(t *testing.T) {
 				Calico: &kops.CalicoNetworkingSpec{
 					IPv4AutoDetectionMethod: "interface=(,en1",
 				},
-				Etcd: kops.EtcdClusterSpec{},
 			},
 			ExpectedErrors: []string{"Invalid value::calico.ipv4AutoDetectionMethod"},
 		},
@@ -596,7 +579,6 @@ func Test_Validate_Calico(t *testing.T) {
 				Calico: &kops.CalicoNetworkingSpec{
 					IPv4AutoDetectionMethod: "interface=foo=bar",
 				},
-				Etcd: kops.EtcdClusterSpec{},
 			},
 			ExpectedErrors: []string{"Invalid value::calico.ipv4AutoDetectionMethod"},
 		},
@@ -606,7 +588,6 @@ func Test_Validate_Calico(t *testing.T) {
 				Calico: &kops.CalicoNetworkingSpec{
 					IPv4AutoDetectionMethod: "=en0,eth.*",
 				},
-				Etcd: kops.EtcdClusterSpec{},
 			},
 			ExpectedErrors: []string{"Invalid value::calico.ipv4AutoDetectionMethod"},
 		},
@@ -616,7 +597,6 @@ func Test_Validate_Calico(t *testing.T) {
 				Calico: &kops.CalicoNetworkingSpec{
 					AWSSrcDstCheck: "off",
 				},
-				Etcd: kops.EtcdClusterSpec{},
 			},
 			ExpectedErrors: []string{"Unsupported value::calico.awsSrcDstCheck"},
 		},
@@ -626,7 +606,6 @@ func Test_Validate_Calico(t *testing.T) {
 				Calico: &kops.CalicoNetworkingSpec{
 					AWSSrcDstCheck: "Enable",
 				},
-				Etcd: kops.EtcdClusterSpec{},
 			},
 		},
 		{
@@ -635,7 +614,6 @@ func Test_Validate_Calico(t *testing.T) {
 				Calico: &kops.CalicoNetworkingSpec{
 					AWSSrcDstCheck: "Disable",
 				},
-				Etcd: kops.EtcdClusterSpec{},
 			},
 		},
 		{
@@ -644,18 +622,43 @@ func Test_Validate_Calico(t *testing.T) {
 				Calico: &kops.CalicoNetworkingSpec{
 					AWSSrcDstCheck: "DoNothing",
 				},
-				Etcd: kops.EtcdClusterSpec{},
 			},
 		},
 		{
-			Description: "unknown Calico encapsulation mode",
+			Description: "encapsulation none with IPv4",
 			Input: caliInput{
+				Cluster: &kops.ClusterSpec{
+					NonMasqueradeCIDR: "100.64.0.0/10",
+				},
 				Calico: &kops.CalicoNetworkingSpec{
-					EncapsulationMode: "None",
+					EncapsulationMode: "none",
 				},
-				Etcd: kops.EtcdClusterSpec{},
 			},
-			ExpectedErrors: []string{"Unsupported value::calico.encapsulationMode"},
+			ExpectedErrors: []string{"Forbidden::calico.encapsulationMode"},
+		},
+		{
+			Description: "encapsulation mode IPIP for IPv6",
+			Input: caliInput{
+				Cluster: &kops.ClusterSpec{
+					NonMasqueradeCIDR: "::/0",
+				},
+				Calico: &kops.CalicoNetworkingSpec{
+					EncapsulationMode: "ipip",
+				},
+			},
+			ExpectedErrors: []string{"Forbidden::calico.encapsulationMode"},
+		},
+		{
+			Description: "encapsulation mode VXLAN for IPv6",
+			Input: caliInput{
+				Cluster: &kops.ClusterSpec{
+					NonMasqueradeCIDR: "::/0",
+				},
+				Calico: &kops.CalicoNetworkingSpec{
+					EncapsulationMode: "vxlan",
+				},
+			},
+			ExpectedErrors: []string{"Forbidden::calico.encapsulationMode"},
 		},
 		{
 			Description: "unknown Calico IPIP mode",
@@ -663,7 +666,6 @@ func Test_Validate_Calico(t *testing.T) {
 				Calico: &kops.CalicoNetworkingSpec{
 					IPIPMode: "unknown",
 				},
-				Etcd: kops.EtcdClusterSpec{},
 			},
 			ExpectedErrors: []string{"Unsupported value::calico.ipipMode"},
 		},
@@ -675,7 +677,6 @@ func Test_Validate_Calico(t *testing.T) {
 				Calico: &kops.CalicoNetworkingSpec{
 					IPIPMode: "Always",
 				},
-				Etcd: kops.EtcdClusterSpec{},
 			},
 		},
 		{
@@ -684,7 +685,6 @@ func Test_Validate_Calico(t *testing.T) {
 				Calico: &kops.CalicoNetworkingSpec{
 					IPIPMode: "CrossSubnet",
 				},
-				Etcd: kops.EtcdClusterSpec{},
 			},
 		},
 		{
@@ -693,87 +693,113 @@ func Test_Validate_Calico(t *testing.T) {
 				Calico: &kops.CalicoNetworkingSpec{
 					IPIPMode: "Never",
 				},
-				Etcd: kops.EtcdClusterSpec{},
 			},
 		},
 		{
 			Description: "Calico IPIP encapsulation mode (explicit) with IPIP IPPool mode (always)",
 			Input: caliInput{
+				Cluster: &kops.ClusterSpec{
+					NonMasqueradeCIDR: "100.64.0.0/10",
+				},
 				Calico: &kops.CalicoNetworkingSpec{
 					EncapsulationMode: "ipip",
 					IPIPMode:          "Always",
 				},
-				Etcd: kops.EtcdClusterSpec{},
 			},
 		},
 		{
 			Description: "Calico IPIP encapsulation mode (explicit) with IPIP IPPool mode (cross-subnet)",
 			Input: caliInput{
+				Cluster: &kops.ClusterSpec{
+					NonMasqueradeCIDR: "100.64.0.0/10",
+				},
 				Calico: &kops.CalicoNetworkingSpec{
 					EncapsulationMode: "ipip",
 					IPIPMode:          "CrossSubnet",
 				},
-				Etcd: kops.EtcdClusterSpec{},
 			},
 		},
 		{
 			Description: "Calico IPIP encapsulation mode (explicit) with IPIP IPPool mode (never)",
 			Input: caliInput{
+				Cluster: &kops.ClusterSpec{
+					NonMasqueradeCIDR: "100.64.0.0/10",
+				},
 				Calico: &kops.CalicoNetworkingSpec{
 					EncapsulationMode: "ipip",
 					IPIPMode:          "Never",
 				},
-				Etcd: kops.EtcdClusterSpec{},
 			},
 		},
 		{
 			Description: "Calico VXLAN encapsulation mode with IPIP IPPool mode",
 			Input: caliInput{
+				Cluster: &kops.ClusterSpec{
+					NonMasqueradeCIDR: "100.64.0.0/10",
+				},
 				Calico: &kops.CalicoNetworkingSpec{
 					EncapsulationMode: "vxlan",
 					IPIPMode:          "Always",
 				},
-				Etcd: kops.EtcdClusterSpec{},
 			},
 			ExpectedErrors: []string{`Forbidden::calico.ipipMode`},
 		},
 		{
 			Description: "Calico VXLAN encapsulation mode with IPIP IPPool mode (always)",
 			Input: caliInput{
+				Cluster: &kops.ClusterSpec{
+					NonMasqueradeCIDR: "100.64.0.0/10",
+				},
 				Calico: &kops.CalicoNetworkingSpec{
 					EncapsulationMode: "vxlan",
 					IPIPMode:          "Always",
 				},
-				Etcd: kops.EtcdClusterSpec{},
 			},
 			ExpectedErrors: []string{`Forbidden::calico.ipipMode`},
 		},
 		{
 			Description: "Calico VXLAN encapsulation mode with IPIP IPPool mode (cross-subnet)",
 			Input: caliInput{
+				Cluster: &kops.ClusterSpec{
+					NonMasqueradeCIDR: "100.64.0.0/10",
+				},
 				Calico: &kops.CalicoNetworkingSpec{
 					EncapsulationMode: "vxlan",
 					IPIPMode:          "CrossSubnet",
 				},
-				Etcd: kops.EtcdClusterSpec{},
 			},
 			ExpectedErrors: []string{`Forbidden::calico.ipipMode`},
 		},
 		{
 			Description: "Calico VXLAN encapsulation mode with IPIP IPPool mode (never)",
 			Input: caliInput{
+				Cluster: &kops.ClusterSpec{
+					NonMasqueradeCIDR: "100.64.0.0/10",
+				},
 				Calico: &kops.CalicoNetworkingSpec{
 					EncapsulationMode: "vxlan",
 					IPIPMode:          "Never",
 				},
-				Etcd: kops.EtcdClusterSpec{},
+			},
+		},
+		{
+			Description: "Calico IPv6 without encapsulation",
+			Input: caliInput{
+				Cluster: &kops.ClusterSpec{
+					NonMasqueradeCIDR: "::/0",
+				},
+				Calico: &kops.CalicoNetworkingSpec{
+					EncapsulationMode: "none",
+					IPIPMode:          "Never",
+					VXLANMode:         "Never",
+				},
 			},
 		},
 	}
 	rootFieldPath := field.NewPath("calico")
 	for _, g := range grid {
 		t.Run(g.Description, func(t *testing.T) {
-			errs := validateNetworkingCalico(g.Input.Calico, g.Input.Etcd, rootFieldPath)
+			errs := validateNetworkingCalico(g.Input.Cluster, g.Input.Calico, rootFieldPath)
 			testErrors(t, g.Input, errs, g.ExpectedErrors)
 		})
 	}
@@ -790,12 +816,12 @@ func Test_Validate_Cilium(t *testing.T) {
 		},
 		{
 			Cilium: kops.CiliumNetworkingSpec{
-				Ipam: "crd",
+				IPAM: "crd",
 			},
 		},
 		{
 			Cilium: kops.CiliumNetworkingSpec{
-				Ipam: "eni",
+				IPAM: "eni",
 			},
 			Spec: kops.ClusterSpec{
 				CloudProvider: "aws",
@@ -803,8 +829,8 @@ func Test_Validate_Cilium(t *testing.T) {
 		},
 		{
 			Cilium: kops.CiliumNetworkingSpec{
-				DisableMasquerade: fi.Bool(true),
-				Ipam:              "eni",
+				Masquerade: fi.Bool(false),
+				IPAM:       "eni",
 			},
 			Spec: kops.ClusterSpec{
 				CloudProvider: "aws",
@@ -812,24 +838,24 @@ func Test_Validate_Cilium(t *testing.T) {
 		},
 		{
 			Cilium: kops.CiliumNetworkingSpec{
-				Ipam: "foo",
+				IPAM: "foo",
 			},
 			ExpectedErrors: []string{"Unsupported value::cilium.ipam"},
 		},
 		{
 			Cilium: kops.CiliumNetworkingSpec{
-				DisableMasquerade: fi.Bool(false),
-				Ipam:              "eni",
+				Masquerade: fi.Bool(true),
+				IPAM:       "eni",
 			},
 			Spec: kops.ClusterSpec{
 				CloudProvider: "aws",
 			},
-			ExpectedErrors: []string{"Forbidden::cilium.disableMasquerade"},
+			ExpectedErrors: []string{"Forbidden::cilium.masquerade"},
 		},
 		{
 			Cilium: kops.CiliumNetworkingSpec{
-				EnableL7Proxy:          fi.Bool(true),
-				IPTablesRulesNoinstall: true,
+				EnableL7Proxy:        fi.Bool(true),
+				InstallIptablesRules: fi.Bool(false),
 			},
 			Spec: kops.ClusterSpec{
 				CloudProvider: "aws",
@@ -838,7 +864,7 @@ func Test_Validate_Cilium(t *testing.T) {
 		},
 		{
 			Cilium: kops.CiliumNetworkingSpec{
-				Ipam: "eni",
+				IPAM: "eni",
 			},
 			Spec: kops.ClusterSpec{
 				CloudProvider: "gce",
