@@ -53,6 +53,10 @@ const (
 	// utilized.
 	SpotInstanceGroupLabelUtilizeReservedInstances = "spotinst.io/utilize-reserved-instances"
 
+	// SpotInstanceGroupLabelUtilizeCommitments is the metadata label used
+	// on the instance group to specify whether commitments should be utilized.
+	SpotInstanceGroupLabelUtilizeCommitments = "spotinst.io/utilize-commitments"
+
 	// SpotInstanceGroupLabelFallbackToOnDemand is the metadata label used on the
 	// instance group to specify whether fallback to on-demand instances should
 	// be enabled.
@@ -218,6 +222,12 @@ func (b *SpotInstanceGroupModelBuilder) buildElastigroup(c *fi.ModelBuilderConte
 				return err
 			}
 
+		case SpotInstanceGroupLabelUtilizeCommitments:
+			group.UtilizeCommitments, err = parseBool(v)
+			if err != nil {
+				return err
+			}
+
 		case SpotInstanceGroupLabelFallbackToOnDemand:
 			group.FallbackToOnDemand, err = parseBool(v)
 			if err != nil {
@@ -380,6 +390,12 @@ func (b *SpotInstanceGroupModelBuilder) buildOcean(c *fi.ModelBuilderContext, ig
 				return err
 			}
 
+		case SpotInstanceGroupLabelUtilizeCommitments:
+			ocean.UtilizeCommitments, err = parseBool(v)
+			if err != nil {
+				return err
+			}
+
 		case SpotInstanceGroupLabelFallbackToOnDemand:
 			ocean.FallbackToOnDemand, err = parseBool(v)
 			if err != nil {
@@ -528,6 +544,11 @@ func (b *SpotInstanceGroupModelBuilder) buildLaunchSpec(c *fi.ModelBuilderContex
 		}
 	}
 
+	policy := ig.Spec.MixedInstancesPolicy
+	if len(launchSpec.InstanceTypes) == 0 && policy != nil && len(policy.Instances) > 0 {
+		launchSpec.InstanceTypes = policy.Instances
+	}
+
 	// Capacity.
 	minSize, maxSize := b.buildCapacity(ig)
 	ocean.MinSize = fi.Int64(fi.Int64Value(ocean.MinSize) + fi.Int64Value(minSize))
@@ -714,7 +735,7 @@ func (b *SpotInstanceGroupModelBuilder) buildRootVolumeOpts(ig *kops.InstanceGro
 
 	// IOPS.
 	{
-		iops := fi.Int32Value(ig.Spec.RootVolumeIops)
+		iops := fi.Int32Value(ig.Spec.RootVolumeIOPS)
 		if iops > 0 {
 			opts.IOPS = fi.Int64(int64(iops))
 		}
