@@ -46,7 +46,9 @@ func (b *ContainerdOptionsBuilder) BuildOptions(o interface{}) error {
 	if clusterSpec.ContainerRuntime == "containerd" {
 		// Set version based on Kubernetes version
 		if fi.StringValue(containerd.Version) == "" {
-			if b.IsKubernetesGTE("1.19") {
+			if b.IsKubernetesGTE("1.23") {
+				containerd.Version = fi.String("1.6.1")
+			} else if b.IsKubernetesGTE("1.19") {
 				containerd.Version = fi.String("1.4.12")
 			} else {
 				containerd.Version = fi.String("1.3.10")
