@@ -59,7 +59,12 @@ func (b *OpenStackOptionsBulder) BuildOptions(o interface{}) error {
 	}
 
 	if clusterSpec.ExternalCloudControllerManager == nil {
-		clusterSpec.ExternalCloudControllerManager = &kops.CloudControllerManagerConfig{}
+		clusterSpec.ExternalCloudControllerManager = &kops.CloudControllerManagerConfig{
+			// No significant downside to always doing a leader election.
+			// Also, having a replicated (HA) control plane requires leader election.
+			LeaderElection: &kops.LeaderElectionConfiguration{LeaderElect: fi.Bool(true)},
+		}
 	}
+
 	return nil
 }
