@@ -24,6 +24,7 @@ import (
 	"k8s.io/kops/pkg/apis/kops"
 	"k8s.io/kops/pkg/apis/kops/model"
 	"k8s.io/kops/pkg/apis/kops/util"
+	"k8s.io/kops/pkg/dns"
 	"k8s.io/kops/pkg/model/components"
 	"k8s.io/kops/pkg/model/iam"
 	nodeidentityaws "k8s.io/kops/pkg/nodeidentity/aws"
@@ -239,7 +240,7 @@ func (b *KopsModelContext) UseBootstrapTokens() bool {
 
 // UsesBastionDns checks if we should use a specific name for the bastion dns
 func (b *KopsModelContext) UsesBastionDns() bool {
-	if b.Cluster.Spec.Topology.Bastion != nil && b.Cluster.Spec.Topology.Bastion.BastionPublicName != "" {
+	if b.Cluster.Spec.Topology.Bastion != nil && b.Cluster.Spec.Topology.Bastion.PublicName != "" {
 		return true
 	}
 	return false
@@ -269,7 +270,7 @@ func (b *KopsModelContext) UseLoadBalancerForAPI() bool {
 // HA - see https://github.com/kubernetes/kops/issues/4252
 func (b *KopsModelContext) UseLoadBalancerForInternalAPI() bool {
 	return b.UseLoadBalancerForAPI() &&
-		b.Cluster.Spec.API.LoadBalancer.UseForInternalApi
+		b.Cluster.Spec.API.LoadBalancer.UseForInternalAPI
 }
 
 // APILoadBalancerClass returns which type of load balancer to use for the api
@@ -309,28 +310,6 @@ func (b *KopsModelContext) UseNetworkLoadBalancer() bool {
 	return b.Cluster.Spec.API.LoadBalancer.Class == kops.LoadBalancerClassNetwork
 }
 
-// UseEtcdManager checks to see if etcd manager is enabled
-func (b *KopsModelContext) UseEtcdManager() bool {
-	for _, x := range b.Cluster.Spec.EtcdClusters {
-		if x.Provider == kops.EtcdProviderTypeManager {
-			return true
-		}
-	}
-
-	return false
-}
-
-// UseEtcdTLS checks to see if etcd tls is enabled
-func (b *KopsModelContext) UseEtcdTLS() bool {
-	for _, x := range b.Cluster.Spec.EtcdClusters {
-		if x.EnableEtcdTLS {
-			return true
-		}
-	}
-
-	return false
-}
-
 // UseSSHKey returns true if SSHKeyName from the cluster spec is set to a nonempty string
 // or there is an SSH public key provisioned in the key store.
 func (b *KopsModelContext) UseSSHKey() bool {
@@ -417,3 +396,18 @@ func (b *KopsModelContext) UseServiceAccountExternalPermissions() bool {
 	return b.Cluster.Spec.IAM != nil &&
 		fi.BoolValue(b.Cluster.Spec.IAM.UseServiceAccountExternalPermissions)
 }
+
+// NetworkingIsCalico returns true if we are using calico networking
+func (b *KopsModelContext) NetworkingIsCalico() bool {
+	return b.Cluster.Spec.Networking != nil && b.Cluster.Spec.Networking.Calico != nil
+}
+
+// NetworkingIsCilium returns true if we are using cilium networking
+func (b *KopsModelContext) NetworkingIsCilium() bool {
+	return b.Cluster.Spec.Networking != nil && b.Cluster.Spec.Networking.Cilium != nil
+}
+
+// IsGossip returns true if we are using gossip instead of "real" DNS
+func (b *KopsModelContext) IsGossip() bool {
+	return dns.IsGossipHostname(b.Cluster.Name)
+}
