@@ -28,6 +28,7 @@ import (
 	nodeidentitygce "k8s.io/kops/pkg/nodeidentity/gce"
 	"k8s.io/kops/upup/pkg/fi"
 	"k8s.io/kops/upup/pkg/fi/cloudup/gce"
+	"k8s.io/kops/upup/pkg/fi/cloudup/gce/gcemetadata"
 	"k8s.io/kops/upup/pkg/fi/cloudup/gcetasks"
 )
 
@@ -48,7 +49,7 @@ var _ fi.ModelBuilder = &AutoscalingGroupModelBuilder{}
 
 // Build the GCE instance template object for an InstanceGroup
 // We are then able to extract out the fields when running with the clusterapi.
-func (b *AutoscalingGroupModelBuilder) buildInstanceTemplate(c *fi.ModelBuilderContext, ig *kops.InstanceGroup) (*gcetasks.InstanceTemplate, error) {
+func (b *AutoscalingGroupModelBuilder) buildInstanceTemplate(c *fi.ModelBuilderContext, ig *kops.InstanceGroup, subnet *kops.ClusterSubnetSpec) (*gcetasks.InstanceTemplate, error) {
 	// Indented to keep diff manageable
 	// TODO: Remove spurious indent
 	{
@@ -97,7 +98,7 @@ func (b *AutoscalingGroupModelBuilder) buildInstanceTemplate(c *fi.ModelBuilderC
 				Metadata: map[string]fi.Resource{
 					"startup-script": startupScript,
 					//"config": resources/config.yaml $nodeset.Name
-					"cluster-name": fi.NewStringResource(b.ClusterName()),
+					gcemetadata.MetadataKeyClusterName:           fi.NewStringResource(b.ClusterName()),
 					nodeidentitygce.MetadataKeyInstanceGroupName: fi.NewStringResource(ig.Name),
 				},
 			}
@@ -137,6 +138,12 @@ func (b *AutoscalingGroupModelBuilder) buildInstanceTemplate(c *fi.ModelBuilderC
 			case kops.InstanceGroupRoleNode:
 				t.Tags = append(t.Tags, b.GCETagForRole(kops.InstanceGroupRoleNode))
 			}
+			roleLabel := gce.GceLabelNameRolePrefix + gce.EncodeGCELabel(strings.ToLower(string(ig.Spec.Role)))
+			t.Labels = map[string]string{
+				gce.GceLabelNameKubernetesCluster: gce.SafeClusterName(b.ClusterName()),
+				roleLabel:                         "",
+				gce.GceLabelNameInstanceGroup:     name,
+			}
 
 			if gce.UsesIPAliases(b.Cluster) {
 				t.CanIPForward = fi.Bool(false)
@@ -144,10 +151,10 @@ func (b *AutoscalingGroupModelBuilder) buildInstanceTemplate(c *fi.ModelBuilderC
 				t.AliasIPRanges = map[string]string{
 					b.NameForIPAliasRange("pods"): "/24",
 				}
-				t.Subnet = b.LinkToIPAliasSubnet()
 			} else {
 				t.CanIPForward = fi.Bool(true)
 			}
+			t.Subnet = b.LinkToSubnet(subnet)
 
 			if b.Cluster.Spec.CloudConfig.GCEServiceAccount != "" {
 				klog.Infof("VMs using Service Account: %v", b.Cluster.Spec.CloudConfig.GCEServiceAccount)
@@ -225,11 +232,23 @@ func (b *AutoscalingGroupModelBuilder) splitToZones(ig *kops.InstanceGroup) (map
 
 func (b *AutoscalingGroupModelBuilder) Build(c *fi.ModelBuilderContext) error {
 	for _, ig := range b.InstanceGroups {
-		instanceTemplate, err := b.buildInstanceTemplate(c, ig)
+		subnets, err := b.GatherSubnets(ig)
 		if err != nil {
 			return err
 		}
 
+		// On GCE, instance groups cannot have multiple subnets.
+		// Because subnets are regional on GCE, this should not be limiting.
+		// (IGs can in theory support multiple zones, but in practice we don't recommend this)
+		if len(subnets) != 1 {
+			return fmt.Errorf("instanceGroup %q has multiple subnets", ig.Name)
+		}
+		subnet := subnets[0]
+
+		instanceTemplate, err := b.buildInstanceTemplate(c, ig, subnet)
+		if err != nil {
+			return err
+		}
 		c.AddTask(instanceTemplate)
 
 		instanceCountByZone, err := b.splitToZones(ig)
