@@ -56,6 +56,54 @@ type Policy struct {
 	Version                   string
 }
 
+func (p *Policy) AddUnconditionalActions(actions ...string) {
+	p.unconditionalAction.Insert(actions...)
+}
+
+func (p *Policy) AddEC2CreateAction(actions, resources []string, partition string) {
+	actualActions := []string{}
+	for _, action := range actions {
+		actualActions = append(actualActions, "ec2:"+action)
+	}
+	actualResources := []string{}
+	for _, resource := range resources {
+		actualResources = append(actualResources, fmt.Sprintf("arn:%s:ec2:*:*:%s/*", partition, resource))
+	}
+
+	p.clusterTaggedCreateAction.Insert(actualActions...)
+
+	p.Statement = append(p.Statement,
+		&Statement{
+			Effect:   StatementEffectAllow,
+			Action:   stringorslice.String("ec2:CreateTags"),
+			Resource: stringorslice.Slice(actualResources),
+			Condition: Condition{
+				"StringEquals": map[string]interface{}{
+					"aws:RequestTag/KubernetesCluster": p.clusterName,
+					"ec2:CreateAction":                 actions,
+				},
+			},
+		},
+
+		&Statement{
+			Effect: StatementEffectAllow,
+			Action: stringorslice.Slice([]string{
+				"ec2:CreateTags",
+				"ec2:DeleteTags", // aws.go, tag.go
+			}),
+			Resource: stringorslice.Slice(actualResources),
+			Condition: Condition{
+				"Null": map[string]string{
+					"aws:RequestTag/KubernetesCluster": "true",
+				},
+				"StringEquals": map[string]string{
+					"aws:ResourceTag/KubernetesCluster": p.clusterName,
+				},
+			},
+		},
+	)
+}
+
 // AsJSON converts the policy document to JSON format (parsable by AWS)
 func (p *Policy) AsJSON() (string, error) {
 	if len(p.unconditionalAction) > 0 {
@@ -89,6 +137,9 @@ func (p *Policy) AsJSON() (string, error) {
 			},
 		})
 	}
+	if len(p.Statement) == 0 {
+		return "", fmt.Errorf("policy contains no statement")
+	}
 
 	j, err := json.MarshalIndent(p, "", "  ")
 	if err != nil {
@@ -258,8 +309,8 @@ func (b *PolicyBuilder) BuildAWSPolicy() (*Policy, error) {
 	// Retrieve all the KMS Keys in use
 	for _, e := range b.Cluster.Spec.EtcdClusters {
 		for _, m := range e.Members {
-			if m.KmsKeyId != nil {
-				b.KMSKeys = append(b.KMSKeys, *m.KmsKeyId)
+			if m.KmsKeyID != nil {
+				b.KMSKeys = append(b.KMSKeys, *m.KmsKeyID)
 			}
 		}
 	}
@@ -287,7 +338,7 @@ func NewPolicy(clusterName string) *Policy {
 func (r *NodeRoleAPIServer) BuildAWSPolicy(b *PolicyBuilder) (*Policy, error) {
 	p := NewPolicy(b.Cluster.GetName())
 
-	addNodeupPermissions(p, r.warmPool)
+	b.addNodeupPermissions(p, r.warmPool)
 
 	var err error
 	if p, err = b.AddS3Permissions(p); err != nil {
@@ -298,7 +349,7 @@ func (r *NodeRoleAPIServer) BuildAWSPolicy(b *PolicyBuilder) (*Policy, error) {
 		addKMSIAMPolicies(p, stringorslice.Slice(b.KMSKeys))
 	}
 
-	if b.Cluster.Spec.IAM.AllowContainerRegistry {
+	if b.Cluster.Spec.IAM != nil && b.Cluster.Spec.IAM.AllowContainerRegistry {
 		addECRPermissions(p)
 	}
 
@@ -306,11 +357,7 @@ func (r *NodeRoleAPIServer) BuildAWSPolicy(b *PolicyBuilder) (*Policy, error) {
 		addAmazonVPCCNIPermissions(p, b.Partition)
 	}
 
-	if b.Cluster.Spec.Networking != nil && b.Cluster.Spec.Networking.LyftVPC != nil {
-		addLyftVPCPermissions(p)
-	}
-
-	if b.Cluster.Spec.Networking != nil && b.Cluster.Spec.Networking.Cilium != nil && b.Cluster.Spec.Networking.Cilium.Ipam == kops.CiliumIpamEni {
+	if b.Cluster.Spec.Networking != nil && b.Cluster.Spec.Networking.Cilium != nil && b.Cluster.Spec.Networking.Cilium.IPAM == kops.CiliumIpamEni {
 		addCiliumEniPermissions(p)
 	}
 
@@ -328,7 +375,11 @@ func (r *NodeRoleMaster) BuildAWSPolicy(b *PolicyBuilder) (*Policy, error) {
 	p := NewPolicy(clusterName)
 
 	addEtcdManagerPermissions(p)
-	addNodeupPermissions(p, false)
+	b.addNodeupPermissions(p, false)
+
+	if b.Cluster.Spec.IsKopsControllerIPAM() {
+		addKopsControllerIPAMPermissions(p)
+	}
 
 	var err error
 	if p, err = b.AddS3Permissions(p); err != nil {
@@ -359,7 +410,7 @@ func (r *NodeRoleMaster) BuildAWSPolicy(b *PolicyBuilder) (*Policy, error) {
 		}
 
 		if b.Cluster.Spec.AWSLoadBalancerController != nil && fi.BoolValue(b.Cluster.Spec.AWSLoadBalancerController.Enabled) {
-			AddAWSLoadbalancerControllerPermissions(p)
+			AddAWSLoadbalancerControllerPermissions(p, b.Partition)
 		}
 		AddClusterAutoscalerPermissions(p)
 
@@ -369,7 +420,7 @@ func (r *NodeRoleMaster) BuildAWSPolicy(b *PolicyBuilder) (*Policy, error) {
 		}
 	}
 
-	if b.Cluster.Spec.IAM.AllowContainerRegistry {
+	if b.Cluster.Spec.IAM != nil && b.Cluster.Spec.IAM.AllowContainerRegistry {
 		addECRPermissions(p)
 	}
 
@@ -377,11 +428,7 @@ func (r *NodeRoleMaster) BuildAWSPolicy(b *PolicyBuilder) (*Policy, error) {
 		addAmazonVPCCNIPermissions(p, b.Partition)
 	}
 
-	if b.Cluster.Spec.Networking != nil && b.Cluster.Spec.Networking.LyftVPC != nil {
-		addLyftVPCPermissions(p)
-	}
-
-	if b.Cluster.Spec.Networking != nil && b.Cluster.Spec.Networking.Cilium != nil && b.Cluster.Spec.Networking.Cilium.Ipam == kops.CiliumIpamEni {
+	if b.Cluster.Spec.Networking != nil && b.Cluster.Spec.Networking.Cilium != nil && b.Cluster.Spec.Networking.Cilium.IPAM == kops.CiliumIpamEni {
 		addCiliumEniPermissions(p)
 	}
 
@@ -396,14 +443,14 @@ func (r *NodeRoleMaster) BuildAWSPolicy(b *PolicyBuilder) (*Policy, error) {
 func (r *NodeRoleNode) BuildAWSPolicy(b *PolicyBuilder) (*Policy, error) {
 	p := NewPolicy(b.Cluster.GetName())
 
-	addNodeupPermissions(p, r.enableLifecycleHookPermissions)
+	b.addNodeupPermissions(p, r.enableLifecycleHookPermissions)
 
 	var err error
 	if p, err = b.AddS3Permissions(p); err != nil {
 		return nil, fmt.Errorf("failed to generate AWS IAM S3 access statements: %v", err)
 	}
 
-	if b.Cluster.Spec.IAM.AllowContainerRegistry {
+	if b.Cluster.Spec.IAM != nil && b.Cluster.Spec.IAM.AllowContainerRegistry {
 		addECRPermissions(p)
 	}
 
@@ -411,10 +458,6 @@ func (r *NodeRoleNode) BuildAWSPolicy(b *PolicyBuilder) (*Policy, error) {
 		addAmazonVPCCNIPermissions(p, b.Partition)
 	}
 
-	if b.Cluster.Spec.Networking != nil && b.Cluster.Spec.Networking.LyftVPC != nil {
-		addLyftVPCPermissions(p)
-	}
-
 	if b.Cluster.Spec.Networking != nil && b.Cluster.Spec.Networking.Calico != nil && b.Cluster.Spec.Networking.Calico.AWSSrcDstCheck != "DoNothing" {
 		addCalicoSrcDstCheckPermissions(p)
 	}
@@ -758,14 +801,27 @@ func addCalicoSrcDstCheckPermissions(p *Policy) {
 	)
 }
 
-func addNodeupPermissions(p *Policy, enableHookSupport bool) {
+func (b *PolicyBuilder) addNodeupPermissions(p *Policy, enableHookSupport bool) {
 	addCertIAMPolicies(p)
 	addKMSGenerateRandomPolicies(p)
 	addASLifecyclePolicies(p, enableHookSupport)
 	p.unconditionalAction.Insert(
+		"ec2:DescribeRegions",
 		"ec2:DescribeInstances", // aws.go
 		"ec2:DescribeInstanceTypes",
 	)
+
+	if b.Cluster.Spec.IsKopsControllerIPAM() {
+		p.unconditionalAction.Insert(
+			"ec2:AssignIpv6Addresses",
+		)
+	}
+}
+
+func addKopsControllerIPAMPermissions(p *Policy) {
+	p.unconditionalAction.Insert(
+		"ec2:DescribeNetworkInterfaces",
+	)
 }
 
 func addEtcdManagerPermissions(p *Policy) {
@@ -893,7 +949,7 @@ func AddCCMPermissions(p *Policy, partition string, cloudRoutes bool) {
 }
 
 // AddAWSLoadbalancerControllerPermissions adds the permissions needed for the aws load balancer controller to the givnen policy
-func AddAWSLoadbalancerControllerPermissions(p *Policy) {
+func AddAWSLoadbalancerControllerPermissions(p *Policy, partition string) {
 	p.unconditionalAction.Insert(
 		"acm:DescribeCertificate",
 		"acm:ListCertificates",
@@ -943,6 +999,15 @@ func AddAWSLoadbalancerControllerPermissions(p *Policy) {
 		"elasticloadbalancing:CreateRule",
 		"elasticloadbalancing:CreateTargetGroup",
 	)
+	p.AddEC2CreateAction(
+		[]string{
+			"CreateSecurityGroup",
+		},
+		[]string{
+			"security-group",
+		},
+		partition,
+	)
 }
 
 func AddClusterAutoscalerPermissions(p *Policy) {
@@ -978,49 +1043,17 @@ func AddAWSEBSCSIDriverPermissions(p *Policy, partition string, appendSnapshotPe
 		"ec2:DeleteVolume",            // aws.go
 		"ec2:DetachVolume",            // aws.go
 	)
-	p.clusterTaggedCreateAction.Insert(
-		"ec2:CreateVolume", // aws.go
-	)
 
-	p.Statement = append(p.Statement,
-		&Statement{
-			Effect: StatementEffectAllow,
-			Action: stringorslice.String(
-				"ec2:CreateTags", // aws.go, tag.go
-			),
-			Resource: stringorslice.Slice(
-				[]string{
-					fmt.Sprintf("arn:%v:ec2:*:*:volume/*", partition),
-					fmt.Sprintf("arn:%v:ec2:*:*:snapshot/*", partition),
-				},
-			),
-			Condition: Condition{
-				"StringEquals": map[string]interface{}{
-					"ec2:CreateAction": []string{
-						"CreateVolume",
-						"CreateSnapshot",
-					},
-				},
-			},
+	p.AddEC2CreateAction(
+		[]string{
+			"CreateVolume",
+			"CreateSnapshot",
 		},
-
-		&Statement{
-			Effect: StatementEffectAllow,
-			Action: stringorslice.String(
-				"ec2:DeleteTags", // aws.go, tag.go
-			),
-			Resource: stringorslice.Slice(
-				[]string{
-					fmt.Sprintf("arn:%v:ec2:*:*:volume/*", partition),
-					fmt.Sprintf("arn:%v:ec2:*:*:snapshot/*", partition),
-				},
-			),
-			Condition: Condition{
-				"StringEquals": map[string]string{
-					"aws:ResourceTag/KubernetesCluster": p.clusterName,
-				},
-			},
+		[]string{
+			"volume",
+			"snapshot",
 		},
+		partition,
 	)
 }
 
@@ -1111,24 +1144,6 @@ func addCertIAMPolicies(p *Policy) {
 	)
 }
 
-func addLyftVPCPermissions(p *Policy) {
-	p.unconditionalAction.Insert(
-		"ec2:AssignPrivateIpAddresses",
-		"ec2:AttachNetworkInterface",
-		"ec2:CreateNetworkInterface",
-		"ec2:DeleteNetworkInterface",
-		"ec2:DescribeInstanceTypes",
-		"ec2:DescribeNetworkInterfaces",
-		"ec2:DescribeSecurityGroups",
-		"ec2:DescribeSubnets",
-		"ec2:DescribeVpcPeeringConnections",
-		"ec2:DescribeVpcs",
-		"ec2:DetachNetworkInterface",
-		"ec2:ModifyNetworkInterfaceAttribute",
-		"ec2:UnassignPrivateIpAddresses",
-	)
-}
-
 func addCiliumEniPermissions(p *Policy) {
 	p.unconditionalAction.Insert(
 		"ec2:DescribeSubnets",
@@ -1150,7 +1165,6 @@ func addAmazonVPCCNIPermissions(p *Policy, partition string) {
 	p.unconditionalAction.Insert(
 		"ec2:AssignPrivateIpAddresses",
 		"ec2:AttachNetworkInterface",
-		"ec2:CreateNetworkInterface",
 		"ec2:DeleteNetworkInterface",
 		"ec2:DescribeInstances",
 		"ec2:DescribeInstanceTypes",
@@ -1159,7 +1173,9 @@ func addAmazonVPCCNIPermissions(p *Policy, partition string) {
 		"ec2:DetachNetworkInterface",
 		"ec2:ModifyNetworkInterfaceAttribute",
 		"ec2:UnassignPrivateIpAddresses",
+		"ec2:CreateNetworkInterface",
 	)
+
 	p.Statement = append(p.Statement,
 		&Statement{
 			Effect: StatementEffectAllow,
