@@ -23,7 +23,6 @@ import (
 
 	compute "google.golang.org/api/compute/v1"
 	clouddns "google.golang.org/api/dns/v1"
-	"k8s.io/apimachinery/pkg/util/sets"
 	"k8s.io/klog/v2"
 	"k8s.io/kops/pkg/dns"
 	"k8s.io/kops/pkg/resources"
@@ -41,8 +40,10 @@ const (
 	typeTargetPool           = "TargetPool"
 	typeFirewallRule         = "FirewallRule"
 	typeForwardingRule       = "ForwardingRule"
+	typeHTTPHealthcheck      = "HTTP HealthCheck"
 	typeAddress              = "Address"
 	typeRoute                = "Route"
+	typeNetwork              = "Network"
 	typeSubnet               = "Subnet"
 	typeRouter               = "Router"
 	typeDNSRecord            = "DNSRecord"
@@ -52,7 +53,12 @@ const (
 // Example: nodeport-external-to-node-ipv6
 const maxPrefixTokens = 5
 
+// Maximum length of a GCE route name
+const maxGCERouteNameLength = 63
+
 func ListResourcesGCE(gceCloud gce.GCECloud, clusterName string, region string) (map[string]*resources.Resource, error) {
+	ctx := context.TODO()
+
 	if region == "" {
 		region = gceCloud.Region()
 	}
@@ -67,7 +73,7 @@ func ListResourcesGCE(gceCloud gce.GCECloud, clusterName string, region string)
 
 	{
 		// TODO: Only zones in api.Cluster object, if we have one?
-		gceZones, err := d.gceCloud.Compute().Zones().List(context.Background(), d.gceCloud.Project())
+		gceZones, err := d.gceCloud.Compute().Zones().List(ctx, d.gceCloud.Project())
 		if err != nil {
 			return nil, fmt.Errorf("error listing zones: %v", err)
 		}
@@ -99,6 +105,7 @@ func ListResourcesGCE(gceCloud gce.GCECloud, clusterName string, region string)
 		d.listAddresses,
 		d.listSubnets,
 		d.listRouters,
+		d.listNetworks,
 	}
 	for _, fn := range listFunctions {
 		resourceTrackers, err := fn()
@@ -111,10 +118,8 @@ func ListResourcesGCE(gceCloud gce.GCECloud, clusterName string, region string)
 	}
 
 	// We try to clean up orphaned routes.
-	// Technically we still have a race condition here - until the master(s) are terminated, they will keep
-	// creating routes.  Another option might be to have a post-destroy cleanup, and only remove routes with no target.
 	{
-		resourceTrackers, err := d.listRoutes(resources)
+		resourceTrackers, err := d.listRoutes(ctx, resources)
 		if err != nil {
 			return nil, err
 		}
@@ -173,6 +178,12 @@ func (d *clusterDiscoveryGCE) listGCEInstanceTemplates() ([]*resources.Resource,
 			Obj: t,
 		}
 
+		for _, ni := range t.Properties.NetworkInterfaces {
+			if ni.Subnetwork != "" {
+				resourceTracker.Blocks = append(resourceTracker.Blocks, typeSubnet+":"+gce.LastComponent(ni.Subnetwork))
+			}
+		}
+
 		klog.V(4).Infof("Found resource: %s", t.SelfLink)
 		resourceTrackers = append(resourceTrackers, resourceTracker)
 	}
@@ -493,7 +504,7 @@ func (d *clusterDiscoveryGCE) listFirewallRules() ([]*resources.Resource, error)
 	}
 
 	for _, fr := range frs {
-		if !d.matchesClusterNameMultipart(fr.Name, maxPrefixTokens) {
+		if !d.matchesClusterNameMultipart(fr.Name, maxPrefixTokens) && !strings.HasPrefix(fr.Name, "k8s-") {
 			continue
 		}
 
@@ -505,7 +516,59 @@ func (d *clusterDiscoveryGCE) listFirewallRules() ([]*resources.Resource, error)
 			}
 		}
 		if !foundMatchingTarget {
-			break
+			continue
+		}
+
+		// find the Kubernetes LoadBalancer
+		if strings.HasPrefix(fr.Name, "k8s-fw-") {
+			name := strings.ReplaceAll(fr.Name, "k8s-fw-", "")
+			fr, err := c.Compute().ForwardingRules().Get(c.Project(), c.Region(), name)
+			if err != nil {
+				return nil, fmt.Errorf("error get ForwardingRule: %v", err)
+			}
+
+			frResourceTracker := &resources.Resource{
+				Name:    fr.Name,
+				ID:      fr.Name,
+				Type:    typeForwardingRule,
+				Deleter: deleteForwardingRule,
+				Obj:     fr,
+			}
+			if fr.Target != "" {
+				frResourceTracker.Blocks = append(frResourceTracker.Blocks, typeTargetPool+":"+gce.LastComponent(fr.Target))
+			}
+			resourceTrackers = append(resourceTrackers, frResourceTracker)
+
+			tp, err := c.Compute().TargetPools().Get(c.Project(), c.Region(), name)
+			if err != nil {
+				return nil, fmt.Errorf("error get TargetPool: %v", err)
+			}
+
+			tpResourceTracker := &resources.Resource{
+				Name:    tp.Name,
+				ID:      tp.Name,
+				Type:    typeTargetPool,
+				Deleter: deleteTargetPool,
+				Obj:     tp,
+			}
+			resourceTrackers = append(resourceTrackers, tpResourceTracker)
+
+		}
+		// l4 level healthchecks
+		if strings.HasPrefix(fr.Name, "k8s-") && strings.HasSuffix(fr.Name, "-http-hc") {
+			name := strings.ReplaceAll(strings.ReplaceAll(fr.Name, "k8s-", ""), "-http-hc", "")
+			hc, err := c.Compute().HTTPHealthChecks().Get(c.Project(), name)
+			if err != nil {
+				return nil, fmt.Errorf("error get HTTPHealthCheck: %v", err)
+			}
+			hcResourceTracker := &resources.Resource{
+				Name:    hc.Name,
+				ID:      hc.Name,
+				Type:    typeHTTPHealthcheck,
+				Deleter: deleteHTTPHealthCheck,
+				Obj:     hc,
+			}
+			resourceTrackers = append(resourceTrackers, hcResourceTracker)
 		}
 
 		resourceTracker := &resources.Resource{
@@ -523,6 +586,29 @@ func (d *clusterDiscoveryGCE) listFirewallRules() ([]*resources.Resource, error)
 	return resourceTrackers, nil
 }
 
+// deleteHTTPHealthCheck is the helper function to delete a Resource for a HTTP health check object
+func deleteHTTPHealthCheck(cloud fi.Cloud, r *resources.Resource) error {
+	c := cloud.(gce.GCECloud)
+	t := r.Obj.(*compute.HttpHealthCheck)
+
+	klog.V(2).Infof("Deleting GCE HTTP HealthCheck %s", t.SelfLink)
+	u, err := gce.ParseGoogleCloudURL(t.SelfLink)
+	if err != nil {
+		return err
+	}
+
+	op, err := c.Compute().HTTPHealthChecks().Delete(u.Project, u.Name)
+	if err != nil {
+		if gce.IsNotFound(err) {
+			klog.Infof("HTTP HealthCheck not found, assuming deleted: %q", t.SelfLink)
+			return nil
+		}
+		return fmt.Errorf("error deleting HTTP HealthCheck %s: %v", t.SelfLink, err)
+	}
+
+	return c.WaitForOp(op)
+}
+
 // deleteFirewallRule is the helper function to delete a Resource for a Firewall object
 func deleteFirewallRule(cloud fi.Cloud, r *resources.Resource) error {
 	c := cloud.(gce.GCECloud)
@@ -546,29 +632,25 @@ func deleteFirewallRule(cloud fi.Cloud, r *resources.Resource) error {
 	return c.WaitForOp(op)
 }
 
-func (d *clusterDiscoveryGCE) listRoutes(resourceMap map[string]*resources.Resource) ([]*resources.Resource, error) {
+func (d *clusterDiscoveryGCE) listRoutes(ctx context.Context, resourceMap map[string]*resources.Resource) ([]*resources.Resource, error) {
 	c := d.gceCloud
 
 	var resourceTrackers []*resources.Resource
 
-	instances := sets.NewString()
+	instancesToDelete := make(map[string]*resources.Resource)
 	for _, resource := range resourceMap {
 		if resource.Type == typeInstance {
-			instances.Insert(resource.ID)
+			instancesToDelete[resource.ID] = resource
 		}
 	}
 
-	prefix := gce.SafeClusterName(d.clusterName) + "-"
-
-	ctx := context.Background()
-
 	// TODO: Push-down prefix?
 	routes, err := c.Compute().Routes().List(ctx, c.Project())
 	if err != nil {
-		return nil, fmt.Errorf("error listing Routes: %v", err)
+		return nil, fmt.Errorf("error listing Routes: %w", err)
 	}
 	for _, r := range routes {
-		if !strings.HasPrefix(r.Name, prefix) {
+		if !d.matchesClusterNameWithUUID(r.Name, maxGCERouteNameLength) {
 			continue
 		}
 		remove := false
@@ -587,7 +669,7 @@ func (d *clusterDiscoveryGCE) listRoutes(resourceMap map[string]*resources.Resou
 				klog.Warningf("error parsing URL for NextHopInstance=%q", r.NextHopInstance)
 			}
 
-			if instances.Has(u.Zone + "/" + u.Name) {
+			if instancesToDelete[u.Zone+"/"+u.Name] != nil {
 				remove = true
 			}
 		}
@@ -601,10 +683,11 @@ func (d *clusterDiscoveryGCE) listRoutes(resourceMap map[string]*resources.Resou
 				Obj:     r,
 			}
 
-			// We don't need to block
-			//if r.NextHopInstance != "" {
-			//	resourceTracker.Blocked = append(resourceTracker.Blocks, typeInstance+":"+gce.LastComponent(r.NextHopInstance))
-			//}
+			// To avoid race conditions where the control-plane re-adds the routes, we delete routes
+			// only after we have deleted all the instances.
+			for _, instance := range instancesToDelete {
+				resourceTracker.Blocked = append(resourceTracker.Blocked, typeInstance+":"+instance.ID)
+			}
 
 			klog.V(4).Infof("Found resource: %s", r.SelfLink)
 			resourceTrackers = append(resourceTrackers, resourceTracker)
@@ -733,8 +816,11 @@ func (d *clusterDiscoveryGCE) listSubnets() ([]*resources.Resource, error) {
 			Type:    typeSubnet,
 			Deleter: deleteSubnet,
 			Obj:     o,
+			Dumper:  DumpSubnetwork,
 		}
 
+		resourceTracker.Blocks = append(resourceTracker.Blocks, typeNetwork+":"+gce.LastComponent(o.Network))
+
 		klog.V(4).Infof("found resource: %s", o.SelfLink)
 		resourceTrackers = append(resourceTrackers, resourceTracker)
 	}
@@ -818,8 +904,85 @@ func deleteRouter(cloud fi.Cloud, r *resources.Resource) error {
 	return c.WaitForOp(op)
 }
 
+func (d *clusterDiscoveryGCE) listNetworks() ([]*resources.Resource, error) {
+	// Templates are very accurate because of the metadata, so use those as the sanity check
+	templates, err := d.findInstanceTemplates()
+	if err != nil {
+		return nil, err
+	}
+	networkUrls := make(map[string]bool)
+	for _, t := range templates {
+		for _, ni := range t.Properties.NetworkInterfaces {
+			if ni.Network != "" {
+				networkUrls[ni.Network] = true
+			}
+		}
+	}
+
+	c := d.gceCloud
+
+	var resourceTrackers []*resources.Resource
+
+	networks, err := c.Compute().Networks().List(c.Project())
+	if err != nil {
+		return nil, fmt.Errorf("error listing networks: %v", err)
+	}
+
+	for _, o := range networks.Items {
+		if o.Name != gce.SafeClusterName(d.clusterName) {
+			klog.V(8).Infof("skipping network with name %q", o.Name)
+			continue
+		}
+
+		if !networkUrls[o.SelfLink] {
+			klog.Warningf("skipping network %q because it didn't match any instance template", o.SelfLink)
+			continue
+		}
+
+		resourceTracker := &resources.Resource{
+			Name:    o.Name,
+			ID:      o.Name,
+			Type:    typeNetwork,
+			Deleter: deleteNetwork,
+			Obj:     o,
+			Dumper:  DumpNetwork,
+		}
+
+		klog.V(4).Infof("found resource: %s", o.SelfLink)
+		resourceTrackers = append(resourceTrackers, resourceTracker)
+	}
+
+	return resourceTrackers, nil
+}
+
+func deleteNetwork(cloud fi.Cloud, r *resources.Resource) error {
+	c := cloud.(gce.GCECloud)
+	o := r.Obj.(*compute.Network)
+
+	klog.V(2).Infof("deleting GCE network %s", o.SelfLink)
+	u, err := gce.ParseGoogleCloudURL(o.SelfLink)
+	if err != nil {
+		return err
+	}
+
+	op, err := c.Compute().Networks().Delete(u.Project, u.Name)
+	if err != nil {
+		if gce.IsNotFound(err) {
+			klog.Infof("network not found, assuming deleted: %q", o.SelfLink)
+			return nil
+		}
+		return fmt.Errorf("error deleting network %s: %v", o.SelfLink, err)
+	}
+
+	return c.WaitForOp(op)
+}
+
 func (d *clusterDiscoveryGCE) matchesClusterName(name string) bool {
-	return d.matchesClusterNameMultipart(name, 1)
+	// Names could have hypens in them, so really there is no limit.
+	// 8 hyphens feels like enough for any "reasonable" name
+	maxParts := 8
+
+	return d.matchesClusterNameMultipart(name, maxParts)
 }
 
 // matchesClusterNameMultipart checks if the name could have been generated by our cluster
@@ -843,6 +1006,26 @@ func (d *clusterDiscoveryGCE) matchesClusterNameMultipart(name string, maxParts
 	return false
 }
 
+// matchesClusterNameWithUUID checks if the name is the clusterName with a UUID on the end.
+// This is used by GCE routes (in "classic" mode)
+func (d *clusterDiscoveryGCE) matchesClusterNameWithUUID(name string, maxLength int) bool {
+	const uuidLength = 36 // e.g. 51a343e2-c285-4e73-b933-18a6ea44c3e4
+
+	// Format is <cluster-name>-<uuid>
+	// <cluster-name> is truncated to ensure it fits into the GCE max length
+	if len(name) < uuidLength {
+		return false
+	}
+	withoutUUID := name[:len(name)-uuidLength]
+
+	clusterPrefix := gce.SafeClusterName(d.clusterName) + "-"
+	if len(clusterPrefix) > maxLength-uuidLength {
+		clusterPrefix = gce.SafeClusterName(d.clusterName)[:maxLength-uuidLength-1] + "-"
+	}
+
+	return clusterPrefix == withoutUUID
+}
+
 func (d *clusterDiscoveryGCE) clusterDNSName() string {
 	return d.clusterName + "."
 }
