@@ -17,12 +17,12 @@ limitations under the License.
 package testutils
 
 import (
-	"io/ioutil"
 	"os"
 	"path"
 	"path/filepath"
 	"testing"
 
+	"google.golang.org/api/compute/v1"
 	"k8s.io/kops/cloudmock/aws/mockeventbridge"
 	"k8s.io/kops/cloudmock/aws/mocksqs"
 
@@ -76,7 +76,7 @@ type IntegrationTestHarness struct {
 
 func NewIntegrationTestHarness(t *testing.T) *IntegrationTestHarness {
 	h := &IntegrationTestHarness{}
-	tempDir, err := ioutil.TempDir("", "test")
+	tempDir, err := os.MkdirTemp("", "test")
 	if err != nil {
 		t.Fatalf("failed to create temp dir: %v", err)
 	}
@@ -294,7 +294,23 @@ func (h *IntegrationTestHarness) SetupMockAWS() *awsup.MockAWSCloud {
 
 // SetupMockGCE configures a mock GCE cloud provider
 func (h *IntegrationTestHarness) SetupMockGCE() *gcemock.MockGCECloud {
-	return gcemock.InstallMockGCECloud("us-test1", "testproject")
+	project := "testproject"
+	region := "us-test1"
+
+	cloud := gcemock.InstallMockGCECloud(region, project)
+
+	cloud.Compute().Networks().Insert(project, &compute.Network{
+		Name:                  "default",
+		AutoCreateSubnetworks: true,
+	})
+
+	cloud.Compute().Subnetworks().Insert(project, region, &compute.Subnetwork{
+		Name:    "default",
+		Network: "default",
+		Region:  region,
+	})
+
+	return cloud
 }
 
 func SetupMockOpenstack() *openstack.MockCloud {
