@@ -79,9 +79,19 @@ func (d *deployer) Up() error {
 			return err
 		}
 	} else {
-		err := d.createCluster(zones, adminAccess)
-		if err != nil {
-			return err
+		if d.terraform != nil {
+			if err := d.createCluster(zones, adminAccess, true); err != nil {
+				return err
+			}
+		} else {
+			// For the non-terraform case, we want to see the preview output.
+			// So run a create (which logs the output), then do an update
+			if err := d.createCluster(zones, adminAccess, false); err != nil {
+				return err
+			}
+			if err := d.updateCluster(true); err != nil {
+				return err
+			}
 		}
 	}
 	isUp, err := d.IsUp()
@@ -95,7 +105,7 @@ func (d *deployer) Up() error {
 	return nil
 }
 
-func (d *deployer) createCluster(zones []string, adminAccess string) error {
+func (d *deployer) createCluster(zones []string, adminAccess string, yes bool) error {
 	args := []string{
 		d.KopsBinaryPath, "create", "cluster",
 		"--name", d.ClusterName,
@@ -103,7 +113,9 @@ func (d *deployer) createCluster(zones []string, adminAccess string) error {
 		"--kubernetes-version", d.KubernetesVersion,
 		"--ssh-public-key", d.SSHPublicKeyPath,
 		"--override", "cluster.spec.nodePortAccess=0.0.0.0/0",
-		"--yes",
+	}
+	if yes {
+		args = append(args, "--yes")
 	}
 
 	if d.CreateArgs != "" {
@@ -119,7 +131,6 @@ func (d *deployer) createCluster(zones []string, adminAccess string) error {
 	args = appendIfUnset(args, "--node-count", "4")
 	args = appendIfUnset(args, "--node-volume-size", "48")
 	args = appendIfUnset(args, "--override", adminAccess)
-	args = appendIfUnset(args, "--admin-access", adminAccess)
 	args = appendIfUnset(args, "--zones", strings.Join(zones, ","))
 
 	switch d.CloudProvider {
@@ -130,7 +141,8 @@ func (d *deployer) createCluster(zones []string, adminAccess string) error {
 		if d.GCPProject != "" {
 			args = appendIfUnset(args, "--project", d.GCPProject)
 		}
-		args = appendIfUnset(args, "--vpc", strings.Split(d.ClusterName, ".")[0])
+		// We used to set the --vpc flag to split clusters into different networks, this is now the default.
+		// args = appendIfUnset(args, "--vpc", strings.Split(d.ClusterName, ".")[0])
 	case "digitalocean":
 		args = appendIfUnset(args, "--master-size", "c2-16vcpu-32gb")
 		args = appendIfUnset(args, "--node-size", "c2-16vcpu-32gb")
@@ -159,6 +171,29 @@ func (d *deployer) createCluster(zones []string, adminAccess string) error {
 	return nil
 }
 
+func (d *deployer) updateCluster(yes bool) error {
+	args := []string{
+		d.KopsBinaryPath, "update", "cluster",
+		"--name", d.ClusterName,
+		"--admin",
+	}
+	if yes {
+		args = append(args, "--yes")
+	}
+
+	klog.Info(strings.Join(args, " "))
+	cmd := exec.Command(args[0], args[1:]...)
+	cmd.SetEnv(d.env()...)
+
+	exec.InheritOutput(cmd)
+	err := cmd.Run()
+	if err != nil {
+		return err
+	}
+
+	return nil
+}
+
 func (d *deployer) IsUp() (bool, error) {
 	wait := d.ValidationWait
 	if wait == 0 {
