@@ -30,6 +30,15 @@ if [[ "$K8S_VERSION_B" == "latest" ]]; then
 fi
 
 export KOPS_BASE_URL
+
+echo "Cleaning up any leaked resources from previous cluster"
+KOPS_BASE_URL=$(kops-base-from-marker "${KOPS_VERSION_B}")
+KOPS_BASE_URL_B="${KOPS_BASE_URL}"
+KOPS_B=$(kops-download-from-base)
+${KUBETEST2} \
+		--down \
+		--kops-binary-path="${KOPS_B}" || echo "kubetest2 down failed"
+
 KOPS_BASE_URL=$(kops-base-from-marker "${KOPS_VERSION_A}")
 KOPS_A=$(kops-download-from-base)
 KOPS="${KOPS_A}"
@@ -47,12 +56,11 @@ KUBECONFIG_A=$(mktemp -t kops.XXXXXXXXX)
 # Verify kubeconfig-a
 kubectl get nodes -owide --kubeconfig="${KUBECONFIG_A}"
 
-KOPS_BASE_URL=$(kops-base-from-marker "${KOPS_VERSION_B}")
-KOPS_B=$(kops-download-from-base)
+KOPS_BASE_URL="${KOPS_BASE_URL_B}"
 
 KOPS="${KOPS_B}"
 
-if [[ "${KOPS_B}" =~ v1.2[01] ]]; then
+if [[ "${KOPS_VERSION_B}" =~ 1.2[01] ]]; then
   "${KOPS_B}" set cluster "${CLUSTER_NAME}" "cluster.spec.kubernetesVersion=${K8S_VERSION_B}"
 else
   "${KOPS_B}" edit cluster "${CLUSTER_NAME}" "--set=cluster.spec.kubernetesVersion=${K8S_VERSION_B}"
@@ -66,6 +74,9 @@ fi
 # Verify kubeconfig-a still works
 kubectl get nodes -owide --kubeconfig "${KUBECONFIG_A}"
 
+# Sleep to ensure channels has done its thing
+sleep 60s
+
 "${KOPS_B}" rolling-update cluster
 "${KOPS_B}" rolling-update cluster --yes --validation-timeout 30m
 
