@@ -100,22 +100,18 @@ func (b *BootstrapChannelBuilder) Build(c *fi.ModelBuilderContext) error {
 		return err
 	}
 
-	if err := addons.Verify(); err != nil {
-		return err
-	}
-
-	for _, a := range addons.Spec.Addons {
+	for _, a := range addons.Items {
 		// Older versions of channels that may be running on the upgrading cluster requires Version to be set
 		// We hardcode version to a high version to ensure an update is triggered on first run, and from then on
 		// only a hash change will trigger an addon update.
-		a.Version = "9.99.0"
+		a.Spec.Version = "9.99.0"
 
-		key := *a.Name
-		if a.Id != "" {
-			key = key + "-" + a.Id
+		key := *a.Spec.Name
+		if a.Spec.Id != "" {
+			key = key + "-" + a.Spec.Id
 		}
 		name := b.Cluster.ObjectMeta.Name + "-addons-" + key
-		manifestPath := "addons/" + *a.Manifest
+		manifestPath := "addons/" + *a.Spec.Manifest
 		klog.V(4).Infof("Addon %q", name)
 
 		manifestResource := b.templates.Find(manifestPath)
@@ -129,7 +125,7 @@ func (b *BootstrapChannelBuilder) Build(c *fi.ModelBuilderContext) error {
 		}
 
 		// Go through any transforms that are best expressed as code
-		remapped, err := addonmanifests.RemapAddonManifest(a, b.KopsModelContext, b.assetBuilder, manifestBytes)
+		remapped, err := addonmanifests.RemapAddonManifest(a.Spec, b.KopsModelContext, b.assetBuilder, manifestBytes)
 		if err != nil {
 			klog.Infof("invalid manifest: %s", string(manifestBytes))
 			return fmt.Errorf("error remapping manifest %s: %v", manifestPath, err)
@@ -139,6 +135,8 @@ func (b *BootstrapChannelBuilder) Build(c *fi.ModelBuilderContext) error {
 		// Trim whitespace
 		manifestBytes = []byte(strings.TrimSpace(string(manifestBytes)))
 
+		a.ManifestData = manifestBytes
+
 		rawManifest := string(manifestBytes)
 		klog.V(4).Infof("Manifest %v", rawManifest)
 
@@ -147,7 +145,7 @@ func (b *BootstrapChannelBuilder) Build(c *fi.ModelBuilderContext) error {
 		if err != nil {
 			return fmt.Errorf("error hashing manifest: %v", err)
 		}
-		a.ManifestHash = manifestHash
+		a.Spec.ManifestHash = manifestHash
 
 		c.AddTask(&fitasks.ManagedFile{
 			Contents:  fi.NewBytesResource(manifestBytes),
@@ -202,7 +200,8 @@ func (b *BootstrapChannelBuilder) Build(c *fi.ModelBuilderContext) error {
 				Name:      fi.String(name),
 			})
 
-			addons.Spec.Addons = append(addons.Spec.Addons, &a.Spec)
+			addon := addons.Add(&a.Spec)
+			addon.ManifestData = manifestBytes
 		}
 
 		b.ClusterAddons = append(b.ClusterAddons, crds...)
@@ -244,10 +243,25 @@ func (b *BootstrapChannelBuilder) Build(c *fi.ModelBuilderContext) error {
 			Name:      fi.String(name),
 		})
 
-		addons.Spec.Addons = append(addons.Spec.Addons, a)
+		addons.Add(a)
 	}
 
-	addonsYAML, err := utils.YamlMarshal(addons)
+	if err := b.addPruneDirectives(addons); err != nil {
+		return err
+	}
+
+	addonsObject := &channelsapi.Addons{}
+	addonsObject.Kind = "Addons"
+	addonsObject.ObjectMeta.Name = "bootstrap"
+	for _, addon := range addons.Items {
+		addonsObject.Spec.Addons = append(addonsObject.Spec.Addons, addon.Spec)
+	}
+
+	if err := addonsObject.Verify(); err != nil {
+		return err
+	}
+
+	addonsYAML, err := utils.YamlMarshal(addonsObject)
 	if err != nil {
 		return fmt.Errorf("error serializing addons yaml: %v", err)
 	}
@@ -264,12 +278,33 @@ func (b *BootstrapChannelBuilder) Build(c *fi.ModelBuilderContext) error {
 	return nil
 }
 
-func (b *BootstrapChannelBuilder) buildAddons(c *fi.ModelBuilderContext) (*channelsapi.Addons, error) {
-	serviceAccountRoles := []iam.Subject{}
+type AddonList struct {
+	Items []*Addon
+}
 
-	addons := &channelsapi.Addons{}
-	addons.Kind = "Addons"
-	addons.ObjectMeta.Name = "bootstrap"
+func (a *AddonList) Add(spec *channelsapi.AddonSpec) *Addon {
+	addon := &Addon{
+		Spec: spec,
+	}
+	a.Items = append(a.Items, addon)
+	return addon
+}
+
+type Addon struct {
+	// Spec is the spec that will (eventually) be passed to the channels binary.
+	Spec *channelsapi.AddonSpec
+
+	// ManifestData is the object data loaded from the manifest.
+	ManifestData []byte
+
+	// BuildPrune is set if we should automatically build prune specifiers, based on the manifest.
+	BuildPrune bool
+}
+
+func (b *BootstrapChannelBuilder) buildAddons(c *fi.ModelBuilderContext) (*AddonList, error) {
+	addons := &AddonList{}
+
+	serviceAccountRoles := []iam.Subject{}
 
 	{
 		key := "kops-controller.addons.k8s.io"
@@ -278,7 +313,7 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.ModelBuilderContext) (*chann
 			location := key + "/k8s-1.16.yaml"
 			id := "k8s-1.16"
 
-			addons.Spec.Addons = append(addons.Spec.Addons, &channelsapi.AddonSpec{
+			addons.Add(&channelsapi.AddonSpec{
 				Name:               fi.String(key),
 				Selector:           map[string]string{"k8s-addon": key},
 				Manifest:           fi.String(location),
@@ -293,7 +328,7 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.ModelBuilderContext) (*chann
 		version := "1.4.0"
 		location := key + "/v" + version + ".yaml"
 
-		addons.Spec.Addons = append(addons.Spec.Addons, &channelsapi.AddonSpec{
+		addons.Add(&channelsapi.AddonSpec{
 			Name:     fi.String(key),
 			Selector: map[string]string{"k8s-addon": key},
 			Manifest: fi.String(location),
@@ -308,7 +343,7 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.ModelBuilderContext) (*chann
 			location := key + "/k8s-1.12.yaml"
 			id := "k8s-1.12"
 
-			addons.Spec.Addons = append(addons.Spec.Addons, &channelsapi.AddonSpec{
+			addons.Add(&channelsapi.AddonSpec{
 				Name:     fi.String(key),
 				Selector: map[string]string{"k8s-addon": key},
 				Manifest: fi.String(location),
@@ -337,7 +372,7 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.ModelBuilderContext) (*chann
 				location := key + "/k8s-1.12.yaml"
 				id := "k8s-1.12"
 
-				addons.Spec.Addons = append(addons.Spec.Addons, &channelsapi.AddonSpec{
+				addons.Add(&channelsapi.AddonSpec{
 					Name:     fi.String(key),
 					Selector: map[string]string{"k8s-addon": key},
 					Manifest: fi.String(location),
@@ -355,7 +390,7 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.ModelBuilderContext) (*chann
 				location := key + "/k8s-1.12.yaml"
 				id := "k8s-1.12"
 
-				addons.Spec.Addons = append(addons.Spec.Addons, &channelsapi.AddonSpec{
+				addons.Add(&channelsapi.AddonSpec{
 					Name:     fi.String(key),
 					Selector: map[string]string{"k8s-addon": key},
 					Manifest: fi.String(location),
@@ -386,7 +421,7 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.ModelBuilderContext) (*chann
 				location := key + "/k8s-1.8.yaml"
 				id := "k8s-1.8"
 
-				addons.Spec.Addons = append(addons.Spec.Addons, &channelsapi.AddonSpec{
+				addons.Add(&channelsapi.AddonSpec{
 					Name:     fi.String(key),
 					Selector: map[string]string{"k8s-addon": key},
 					Manifest: fi.String(location),
@@ -406,7 +441,38 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.ModelBuilderContext) (*chann
 			location := key + "/k8s-1.9.yaml"
 			id := "k8s-1.9"
 
-			addons.Spec.Addons = append(addons.Spec.Addons, &channelsapi.AddonSpec{
+			addons.Add(&channelsapi.AddonSpec{
+				Name:     fi.String(key),
+				Selector: map[string]string{"k8s-addon": key},
+				Manifest: fi.String(location),
+				Id:       id,
+			})
+		}
+	}
+
+	if b.IsKubernetesGTE("1.23") && b.IsKubernetesLT("1.26") &&
+		(kops.CloudProviderID(b.Cluster.Spec.CloudProvider) == kops.CloudProviderAWS ||
+			kops.CloudProviderID(b.Cluster.Spec.CloudProvider) == kops.CloudProviderGCE) {
+		// AWS and GCE KCM-to-CCM leader migration
+		key := "leader-migration.rbac.addons.k8s.io"
+
+		if b.IsKubernetesLT("1.25") {
+			location := key + "/k8s-1.23.yaml"
+			id := "k8s-1.23"
+
+			addons.Add(&channelsapi.AddonSpec{
+				Name:     fi.String(key),
+				Selector: map[string]string{"k8s-addon": key},
+				Manifest: fi.String(location),
+				Id:       id,
+			})
+		}
+
+		if b.IsKubernetesGTE("1.25") {
+			location := key + "/k8s-1.25.yaml"
+			id := "k8s-1.25"
+
+			addons.Add(&channelsapi.AddonSpec{
 				Name:     fi.String(key),
 				Selector: map[string]string{"k8s-addon": key},
 				Manifest: fi.String(location),
@@ -420,7 +486,7 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.ModelBuilderContext) (*chann
 		version := "1.5.0"
 		location := key + "/v" + version + ".yaml"
 
-		addons.Spec.Addons = append(addons.Spec.Addons, &channelsapi.AddonSpec{
+		addons.Add(&channelsapi.AddonSpec{
 			Name:     fi.String(key),
 			Selector: map[string]string{"k8s-addon": key},
 			Manifest: fi.String(location),
@@ -428,31 +494,25 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.ModelBuilderContext) (*chann
 	}
 
 	if b.Cluster.Spec.ExternalDNS == nil || b.Cluster.Spec.ExternalDNS.Provider == kops.ExternalDNSProviderDNSController {
-		// @check the dns-controller has not been disabled
-		externalDNS := b.Cluster.Spec.ExternalDNS
-		if externalDNS == nil || !externalDNS.Disable {
-			{
-				key := "dns-controller.addons.k8s.io"
+		{
+			key := "dns-controller.addons.k8s.io"
+			location := key + "/k8s-1.12.yaml"
+			id := "k8s-1.12"
 
-				{
-					location := key + "/k8s-1.12.yaml"
-					id := "k8s-1.12"
-
-					addons.Spec.Addons = append(addons.Spec.Addons, &channelsapi.AddonSpec{
-						Name:     fi.String(key),
-						Selector: map[string]string{"k8s-addon": key},
-						Manifest: fi.String(location),
-						Id:       id,
-					})
-				}
-			}
-
-			// Generate dns-controller ServiceAccount IAM permissions
-			if b.UseServiceAccountExternalPermissions() {
-				serviceAccountRoles = append(serviceAccountRoles, &dnscontroller.ServiceAccount{})
-			}
+			addons.Add(&channelsapi.AddonSpec{
+				Name:     fi.String(key),
+				Selector: map[string]string{"k8s-addon": key},
+				Manifest: fi.String(location),
+				Id:       id,
+			})
 		}
-	} else {
+
+		// Generate dns-controller ServiceAccount IAM permissions.
+		// Gossip clsuters do not require any cloud permissions.
+		if b.UseServiceAccountExternalPermissions() && !b.IsGossip() {
+			serviceAccountRoles = append(serviceAccountRoles, &dnscontroller.ServiceAccount{})
+		}
+	} else if b.Cluster.Spec.ExternalDNS.Provider == kops.ExternalDNSProviderExternalDNS {
 		{
 			key := "external-dns.addons.k8s.io"
 
@@ -465,7 +525,7 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.ModelBuilderContext) (*chann
 					id = "k8s-1.12"
 				}
 
-				addons.Spec.Addons = append(addons.Spec.Addons, &channelsapi.AddonSpec{
+				addons.Add(&channelsapi.AddonSpec{
 					Name:     fi.String(key),
 					Selector: map[string]string{"k8s-addon": key},
 					Manifest: fi.String(location),
@@ -489,7 +549,7 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.ModelBuilderContext) (*chann
 				location := key + "/k8s-1.12.yaml"
 				id := "k8s-1.12"
 
-				addons.Spec.Addons = append(addons.Spec.Addons, &channelsapi.AddonSpec{
+				addons.Add(&channelsapi.AddonSpec{
 					Name:     fi.String(key),
 					Selector: map[string]string{"k8s-addon": key},
 					Manifest: fi.String(location),
@@ -507,7 +567,7 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.ModelBuilderContext) (*chann
 				location := key + "/k8s-1.15.yaml"
 				id := "k8s-1.15"
 
-				addons.Spec.Addons = append(addons.Spec.Addons, &channelsapi.AddonSpec{
+				addons.Add(&channelsapi.AddonSpec{
 					Name:     fi.String(key),
 					Selector: map[string]string{"k8s-addon": key},
 					Manifest: fi.String(location),
@@ -530,7 +590,7 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.ModelBuilderContext) (*chann
 				location := key + "/k8s-1.11.yaml"
 				id := "k8s-1.11"
 
-				addons.Spec.Addons = append(addons.Spec.Addons, &channelsapi.AddonSpec{
+				addons.Add(&channelsapi.AddonSpec{
 					Name:     fi.String(key),
 					Selector: map[string]string{"k8s-app": "metrics-server"},
 					Manifest: fi.String(location),
@@ -549,7 +609,7 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.ModelBuilderContext) (*chann
 				location := key + "/k8s-1.16.yaml"
 				id := "k8s-1.16"
 
-				addons.Spec.Addons = append(addons.Spec.Addons, &channelsapi.AddonSpec{
+				addons.Add(&channelsapi.AddonSpec{
 					Name:     fi.String(key),
 					Manifest: fi.String(location),
 					Id:       id,
@@ -568,12 +628,13 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.ModelBuilderContext) (*chann
 			location := key + "/k8s-1.11.yaml"
 			id := "k8s-1.11"
 
-			addons.Spec.Addons = append(addons.Spec.Addons, &channelsapi.AddonSpec{
+			addon := addons.Add(&channelsapi.AddonSpec{
 				Name:     fi.String(key),
 				Selector: map[string]string{"k8s-addon": key},
 				Manifest: fi.String(location),
 				Id:       id,
 			})
+			addon.BuildPrune = true
 		}
 
 		if b.UseServiceAccountExternalPermissions() {
@@ -591,7 +652,7 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.ModelBuilderContext) (*chann
 			location := key + "/k8s-1.17.yaml"
 			id := "k8s-1.17"
 
-			addons.Spec.Addons = append(addons.Spec.Addons, &channelsapi.AddonSpec{
+			addons.Add(&channelsapi.AddonSpec{
 				Name:     fi.String(key),
 				Selector: map[string]string{"k8s-addon": key},
 				Manifest: fi.String(location),
@@ -610,7 +671,7 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.ModelBuilderContext) (*chann
 			location := key + "/k8s-1.16.yaml"
 			id := "k8s-1.16"
 
-			addons.Spec.Addons = append(addons.Spec.Addons, &channelsapi.AddonSpec{
+			addons.Add(&channelsapi.AddonSpec{
 				Name:     fi.String(key),
 				Selector: map[string]string{"k8s-addon": key},
 				Manifest: fi.String(location),
@@ -627,7 +688,7 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.ModelBuilderContext) (*chann
 			location := key + "/k8s-1.9.yaml"
 			id := "k8s-1.9"
 
-			addons.Spec.Addons = append(addons.Spec.Addons, &channelsapi.AddonSpec{
+			addons.Add(&channelsapi.AddonSpec{
 				Name:     fi.String(key),
 				Selector: map[string]string{"k8s-addon": key},
 				Manifest: fi.String(location),
@@ -638,7 +699,7 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.ModelBuilderContext) (*chann
 			location := key + "/k8s-1.19.yaml"
 			id := "k8s-1.19"
 
-			addons.Spec.Addons = append(addons.Spec.Addons, &channelsapi.AddonSpec{
+			addons.Add(&channelsapi.AddonSpec{
 				Name:     fi.String(key),
 				Selector: map[string]string{"k8s-addon": key},
 				Manifest: fi.String(location),
@@ -653,6 +714,26 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.ModelBuilderContext) (*chann
 		}
 	}
 
+	if b.Cluster.Spec.PodIdentityWebhook != nil && fi.BoolValue(&b.Cluster.Spec.PodIdentityWebhook.Enabled) {
+
+		key := "eks-pod-identity-webhook.addons.k8s.io"
+
+		{
+			id := "k8s-1.16"
+			location := key + "/" + id + ".yaml"
+
+			addons.Add(&channelsapi.AddonSpec{
+				Name: fi.String(key),
+				Selector: map[string]string{
+					"k8s-addon": key,
+				},
+				Manifest: fi.String(location),
+				Id:       id,
+				NeedsPKI: true,
+			})
+		}
+	}
+
 	if kops.CloudProviderID(b.Cluster.Spec.CloudProvider) == kops.CloudProviderAWS {
 		key := "storage-aws.addons.k8s.io"
 
@@ -660,7 +741,7 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.ModelBuilderContext) (*chann
 			id := "v1.15.0"
 			location := key + "/" + id + ".yaml"
 
-			addons.Spec.Addons = append(addons.Spec.Addons, &channelsapi.AddonSpec{
+			addons.Add(&channelsapi.AddonSpec{
 				Name:     fi.String(key),
 				Selector: map[string]string{"k8s-addon": key},
 				Manifest: fi.String(location),
@@ -676,7 +757,7 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.ModelBuilderContext) (*chann
 			id := "k8s-1.8"
 			location := key + "/" + id + ".yaml"
 
-			addons.Spec.Addons = append(addons.Spec.Addons, &channelsapi.AddonSpec{
+			addons.Add(&channelsapi.AddonSpec{
 				Name:     fi.String(key),
 				Selector: map[string]string{"k8s-addon": key},
 				Manifest: fi.String(location),
@@ -692,13 +773,27 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.ModelBuilderContext) (*chann
 			id := "v1.7.0"
 			location := key + "/" + id + ".yaml"
 
-			addons.Spec.Addons = append(addons.Spec.Addons, &channelsapi.AddonSpec{
+			addons.Add(&channelsapi.AddonSpec{
 				Name:     fi.String(key),
 				Selector: map[string]string{"k8s-addon": key},
 				Manifest: fi.String(location),
 				Id:       id,
 			})
 		}
+
+		if b.Cluster.Spec.CloudConfig != nil && b.Cluster.Spec.CloudConfig.GCPPDCSIDriver != nil && fi.BoolValue(b.Cluster.Spec.CloudConfig.GCPPDCSIDriver.Enabled) {
+			key := "gcp-pd-csi-driver.addons.k8s.io"
+			{
+				id := "k8s-1.23"
+				location := key + "/" + id + ".yaml"
+				addons.Add(&channelsapi.AddonSpec{
+					Name:     fi.String(key),
+					Manifest: fi.String(location),
+					Selector: map[string]string{"k8s-addon": key},
+					Id:       id,
+				})
+			}
+		}
 	}
 
 	if featureflag.Spotinst.Enabled() && featureflag.SpotinstController.Enabled() {
@@ -708,7 +803,7 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.ModelBuilderContext) (*chann
 			id := "v1.14.0"
 			location := key + "/" + id + ".yaml"
 
-			addons.Spec.Addons = append(addons.Spec.Addons, &channelsapi.AddonSpec{
+			addons.Add(&channelsapi.AddonSpec{
 				Name:     fi.String(key),
 				Selector: map[string]string{"k8s-addon": key},
 				Manifest: fi.String(location),
@@ -726,13 +821,29 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.ModelBuilderContext) (*chann
 			id := "v0.1.12"
 			location := key + "/" + id + ".yaml"
 
-			addons.Spec.Addons = append(addons.Spec.Addons, &channelsapi.AddonSpec{
+			addons.Add(&channelsapi.AddonSpec{
 				Name:     fi.String(key),
 				Selector: map[string]string{"k8s-addon": key},
 				Manifest: fi.String(location),
 				Id:       id,
 			})
 		}
+
+		if kops.CloudProviderID(b.Cluster.Spec.CloudProvider) == kops.CloudProviderGCE {
+			if b.Cluster.Spec.ExternalCloudControllerManager != nil {
+				key := "gcp-cloud-controller.addons.k8s.io"
+				{
+					id := "k8s-1.23"
+					location := key + "/" + id + ".yaml"
+					addons.Add(&channelsapi.AddonSpec{
+						Name:     fi.String(key),
+						Manifest: fi.String(location),
+						Selector: map[string]string{"k8s-addon": key},
+						Id:       id,
+					})
+				}
+			}
+		}
 	}
 
 	if b.Cluster.Spec.Networking.Kopeio != nil {
@@ -742,12 +853,14 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.ModelBuilderContext) (*chann
 			location := key + "/k8s-1.12.yaml"
 			id := "k8s-1.12"
 
-			addons.Spec.Addons = append(addons.Spec.Addons, &channelsapi.AddonSpec{
+			addon := addons.Add(&channelsapi.AddonSpec{
 				Name:     fi.String(key),
 				Selector: networkingSelector(),
 				Manifest: fi.String(location),
 				Id:       id,
 			})
+
+			addon.BuildPrune = true
 		}
 	}
 
@@ -758,7 +871,7 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.ModelBuilderContext) (*chann
 			location := key + "/k8s-1.12.yaml"
 			id := "k8s-1.12"
 
-			addons.Spec.Addons = append(addons.Spec.Addons, &channelsapi.AddonSpec{
+			addons.Add(&channelsapi.AddonSpec{
 				Name:     fi.String(key),
 				Selector: networkingSelector(),
 				Manifest: fi.String(location),
@@ -774,7 +887,7 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.ModelBuilderContext) (*chann
 			location := key + "/k8s-1.12.yaml"
 			id := "k8s-1.12"
 
-			addons.Spec.Addons = append(addons.Spec.Addons, &channelsapi.AddonSpec{
+			addons.Add(&channelsapi.AddonSpec{
 				Name:     fi.String(key),
 				Selector: networkingSelector(),
 				Manifest: fi.String(location),
@@ -790,7 +903,7 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.ModelBuilderContext) (*chann
 			id := "k8s-1.16"
 			location := key + "/" + id + ".yaml"
 
-			addons.Spec.Addons = append(addons.Spec.Addons, &channelsapi.AddonSpec{
+			addons.Add(&channelsapi.AddonSpec{
 				Name:     fi.String(key),
 				Selector: networkingSelector(),
 				Manifest: fi.String(location),
@@ -806,7 +919,7 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.ModelBuilderContext) (*chann
 			id := "k8s-1.22"
 			location := key + "/" + id + ".yaml"
 
-			addons.Spec.Addons = append(addons.Spec.Addons, &channelsapi.AddonSpec{
+			addons.Add(&channelsapi.AddonSpec{
 				Name:     fi.String(key),
 				Selector: networkingSelector(),
 				Manifest: fi.String(location),
@@ -816,7 +929,7 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.ModelBuilderContext) (*chann
 			id := "k8s-1.16"
 			location := key + "/" + id + ".yaml"
 
-			addons.Spec.Addons = append(addons.Spec.Addons, &channelsapi.AddonSpec{
+			addons.Add(&channelsapi.AddonSpec{
 				Name:     fi.String(key),
 				Selector: networkingSelector(),
 				Manifest: fi.String(location),
@@ -832,7 +945,7 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.ModelBuilderContext) (*chann
 			location := key + "/k8s-1.12.yaml"
 			id := "k8s-1.12"
 
-			addons.Spec.Addons = append(addons.Spec.Addons, &channelsapi.AddonSpec{
+			addons.Add(&channelsapi.AddonSpec{
 				Name:     fi.String(key),
 				Selector: networkingSelector(),
 				Manifest: fi.String(location),
@@ -848,7 +961,7 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.ModelBuilderContext) (*chann
 			id := "k8s-1.16"
 			location := key + "/" + id + ".yaml"
 
-			addons.Spec.Addons = append(addons.Spec.Addons, &channelsapi.AddonSpec{
+			addons.Add(&channelsapi.AddonSpec{
 				Name:               fi.String(key),
 				Selector:           networkingSelector(),
 				Manifest:           fi.String(location),
@@ -873,7 +986,7 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.ModelBuilderContext) (*chann
 				location := key + "/k8s-1.12.yaml"
 				id := "k8s-1.12"
 
-				addons.Spec.Addons = append(addons.Spec.Addons, &channelsapi.AddonSpec{
+				addons.Add(&channelsapi.AddonSpec{
 					Name:     fi.String(key),
 					Selector: authenticationSelector,
 					Manifest: fi.String(location),
@@ -881,14 +994,14 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.ModelBuilderContext) (*chann
 				})
 			}
 		}
-		if b.Cluster.Spec.Authentication.Aws != nil {
+		if b.Cluster.Spec.Authentication.AWS != nil {
 			key := "authentication.aws"
 
 			{
 				location := key + "/k8s-1.12.yaml"
 				id := "k8s-1.12"
 
-				addons.Spec.Addons = append(addons.Spec.Addons, &channelsapi.AddonSpec{
+				addons.Add(&channelsapi.AddonSpec{
 					Name:     fi.String(key),
 					Selector: authenticationSelector,
 					Manifest: fi.String(location),
@@ -905,7 +1018,7 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.ModelBuilderContext) (*chann
 			id := "k8s-1.16"
 			location := key + "/" + id + ".yaml"
 
-			addons.Spec.Addons = append(addons.Spec.Addons, &channelsapi.AddonSpec{
+			addons.Add(&channelsapi.AddonSpec{
 				Name:     fi.String(key),
 				Manifest: fi.String(location),
 				Selector: map[string]string{"k8s-addon": key},
@@ -921,7 +1034,7 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.ModelBuilderContext) (*chann
 				location := key + "/k8s-1.13.yaml"
 				id := "k8s-1.13-ccm"
 
-				addons.Spec.Addons = append(addons.Spec.Addons, &channelsapi.AddonSpec{
+				addons.Add(&channelsapi.AddonSpec{
 					Name:     fi.String(key),
 					Manifest: fi.String(location),
 					Selector: map[string]string{"k8s-addon": key},
@@ -935,7 +1048,7 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.ModelBuilderContext) (*chann
 				location := key + "/k8s-1.12.yaml"
 				id := "k8s-1.12-ccm"
 
-				addons.Spec.Addons = append(addons.Spec.Addons, &channelsapi.AddonSpec{
+				addons.Add(&channelsapi.AddonSpec{
 					Name:     fi.String(key),
 					Selector: map[string]string{"k8s-addon": key},
 					Manifest: fi.String(location),
@@ -947,13 +1060,13 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.ModelBuilderContext) (*chann
 
 	if kops.CloudProviderID(b.Cluster.Spec.CloudProvider) == kops.CloudProviderAWS {
 
-		if b.IsKubernetesGTE("1.18") && b.Cluster.Spec.ExternalCloudControllerManager != nil {
+		if b.Cluster.Spec.ExternalCloudControllerManager != nil {
 			key := "aws-cloud-controller.addons.k8s.io"
 
 			{
 				id := "k8s-1.18"
 				location := key + "/" + id + ".yaml"
-				addons.Spec.Addons = append(addons.Spec.Addons, &channelsapi.AddonSpec{
+				addons.Add(&channelsapi.AddonSpec{
 					Name:     fi.String(key),
 					Manifest: fi.String(location),
 					Selector: map[string]string{"k8s-addon": key},
@@ -970,15 +1083,13 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.ModelBuilderContext) (*chann
 			{
 				id := "k8s-1.17"
 				location := key + "/" + id + ".yaml"
-				addons.Spec.Addons = append(addons.Spec.Addons, &channelsapi.AddonSpec{
+				addons.Add(&channelsapi.AddonSpec{
 					Name:     fi.String(key),
 					Manifest: fi.String(location),
 					Selector: map[string]string{"k8s-addon": key},
 					Id:       id,
 				})
 			}
-
-			// Generate aws-load-balancer-controller ServiceAccount IAM permissions
 			if b.UseServiceAccountExternalPermissions() {
 				serviceAccountRoles = append(serviceAccountRoles, &awsebscsidriver.ServiceAccount{})
 			}
@@ -991,7 +1102,7 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.ModelBuilderContext) (*chann
 		{
 			id := "k8s-1.20"
 			location := key + "/" + id + ".yaml"
-			addons.Spec.Addons = append(addons.Spec.Addons, &channelsapi.AddonSpec{
+			addons.Add(&channelsapi.AddonSpec{
 				Name:     fi.String(key),
 				Manifest: fi.String(location),
 				Selector: map[string]string{"k8s-addon": key},
@@ -1006,7 +1117,7 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.ModelBuilderContext) (*chann
 		version := "1.7.0"
 		location := key + "/v" + version + ".yaml"
 
-		addons.Spec.Addons = append(addons.Spec.Addons, &channelsapi.AddonSpec{
+		addons.Add(&channelsapi.AddonSpec{
 			Name:     fi.String(key),
 			Selector: map[string]string{"k8s-addon": key},
 			Manifest: fi.String(location),
