@@ -30,8 +30,11 @@ import (
 )
 
 const (
+	// containerd packages URLs for v1.6.x+
+	containerdReleaseUrlAmd64 = "https://github.com/containerd/containerd/releases/download/v%s/containerd-%s-linux-amd64.tar.gz"
+	containerdReleaseUrlArm64 = "https://github.com/containerd/containerd/releases/download/v%s/containerd-%s-linux-arm64.tar.gz"
 	// containerd packages URLs for v1.4.x+
-	containerdVersionUrlAmd64 = "https://github.com/containerd/containerd/releases/download/v%s/cri-containerd-cni-%s-linux-amd64.tar.gz"
+	containerdBundleUrlAmd64 = "https://github.com/containerd/containerd/releases/download/v%s/cri-containerd-cni-%s-linux-amd64.tar.gz"
 	// containerd legacy packages URLs for v1.2.x and v1.3.x
 	containerdLegacyUrlAmd64 = "https://storage.googleapis.com/cri-containerd-release/cri-containerd-%s.linux-amd64.tar.gz"
 	// containerd version that is available for both AMD64 and ARM64, used in case the selected version is not available for ARM64
@@ -116,14 +119,17 @@ func findContainerdVersionUrl(arch architectures.Architecture, version string) (
 	var u string
 	switch arch {
 	case architectures.ArchitectureAmd64:
-		if sv.GTE(semver.MustParse("1.3.8")) {
-			u = fmt.Sprintf(containerdVersionUrlAmd64, version, version)
+		if sv.GTE(semver.MustParse("1.6.0")) {
+			u = fmt.Sprintf(containerdReleaseUrlAmd64, version, version)
+		} else if sv.GTE(semver.MustParse("1.3.8")) {
+			u = fmt.Sprintf(containerdBundleUrlAmd64, version, version)
 		} else {
 			u = fmt.Sprintf(containerdLegacyUrlAmd64, version)
 		}
 	case architectures.ArchitectureArm64:
-		// For now there are only official AMD64 builds, always using fallback Docker version instead
-		if findAllContainerdHashesAmd64()[version] != "" {
+		if sv.GTE(semver.MustParse("1.6.0")) {
+			u = fmt.Sprintf(containerdReleaseUrlArm64, version, version)
+		} else if findAllContainerdHashesAmd64()[version] != "" {
 			if findAllContainerdDockerMappings()[version] != "" {
 				u = fmt.Sprintf(dockerVersionUrlArm64, findAllContainerdDockerMappings()[version])
 			} else {
@@ -155,8 +161,9 @@ func findContainerdVersionHash(arch architectures.Architecture, version string)
 	case architectures.ArchitectureAmd64:
 		h = findAllContainerdHashesAmd64()[version]
 	case architectures.ArchitectureArm64:
-		// For now there are only official AMD64 builds, always using fallback Docker version instead
-		if findAllContainerdHashesAmd64()[version] != "" {
+		if sv.GTE(semver.MustParse("1.6.0")) {
+			h = findAllContainerdHashesArm64()[version]
+		} else if findAllContainerdHashesAmd64()[version] != "" {
 			if findAllContainerdDockerMappings()[version] != "" {
 				h = findAllDockerHashesArm64()[findAllContainerdDockerMappings()[version]]
 			} else {
@@ -201,6 +208,18 @@ func findAllContainerdHashesAmd64() map[string]string {
 		"1.5.6":  "afc51718ebe46cb9b985edac816e63fe86c07e37d28cdd21b2c0302dec6fa7ae",
 		"1.5.7":  "7fce75bab43a39d6f9efb3c370de2da49723f0e1dbaa9732d68fa7f620d720c8",
 		"1.5.8":  "5dbb7f43c0ac1fda79999ff63e648926e3464d7d1034402ee2117e6a93868431",
+		"1.5.9":  "f64c8e3b736b370c963b08c33ac70f030fc311bc48fcfd00461465af2fff3488",
+		"1.6.0":  "f77725e4f757523bf1472ec3b9e02b09303a5d99529173be0f11a6d39f5676e9",
+		"1.6.1":  "c1df0a12af2be019ca2d6c157f94e8ce7430484ab29948c9805882df40ec458b",
+	}
+
+	return hashes
+}
+
+func findAllContainerdHashesArm64() map[string]string {
+	hashes := map[string]string{
+		"1.6.0": "6eff3e16d44c89e1e8480a9ca078f79bab82af602818455cc162be344f64686a",
+		"1.6.1": "fbeec71f2d37e0e4ceaaac2bdf081295add940a7a5c7a6bcc125e5bbae067791",
 	}
 
 	return hashes
