@@ -35,6 +35,8 @@ type Network struct {
 	Mode      string
 
 	CIDR *string
+
+	Shared *bool
 }
 
 var _ fi.CompareWithID = &Network{}
@@ -55,7 +57,6 @@ func (e *Network) Find(c *fi.Context) (*Network, error) {
 	}
 
 	actual := &Network{}
-	actual.Name = &r.Name
 	if r.IPv4Range != "" {
 		actual.Mode = "legacy"
 		actual.CIDR = &r.IPv4Range
@@ -71,6 +72,13 @@ func (e *Network) Find(c *fi.Context) (*Network, error) {
 
 	// Ignore "system" fields
 	actual.Lifecycle = e.Lifecycle
+	actual.Shared = e.Shared
+	actual.Name = e.Name
+
+	// Match unspecified values
+	if e.Mode == "" {
+		e.Mode = actual.Mode
+	}
 
 	return actual, nil
 }
@@ -108,6 +116,13 @@ func (_ *Network) CheckChanges(a, e, changes *Network) error {
 	case "auto":
 	case "custom":
 	case "legacy":
+		// Known
+
+	case "":
+		// Treated as "keep existing", only allowed for shared mode
+		if !fi.BoolValue(e.Shared) {
+			return fmt.Errorf("must specify mode for (non-shared) Network")
+		}
 
 	default:
 		return fmt.Errorf("unknown mode %q for Network", e.Mode)
@@ -117,6 +132,14 @@ func (_ *Network) CheckChanges(a, e, changes *Network) error {
 }
 
 func (_ *Network) RenderGCE(t *gce.GCEAPITarget, a, e, changes *Network) error {
+	shared := fi.BoolValue(e.Shared)
+	if shared {
+		// Verify the network was found
+		if a == nil {
+			return fmt.Errorf("Network with name %q not found", fi.StringValue(e.Name))
+		}
+	}
+
 	if a == nil {
 		klog.V(2).Infof("Creating Network with CIDR: %q", fi.StringValue(e.CIDR))
 
@@ -138,11 +161,18 @@ func (_ *Network) RenderGCE(t *gce.GCEAPITarget, a, e, changes *Network) error {
 			// the auto-create subnetworks default of "true". Explicitly send
 			// the default value.
 			network.ForceSendFields = []string{"AutoCreateSubnetworks"}
+
+		default:
+			return fmt.Errorf("unhandled mode %q", e.Mode)
 		}
-		_, err := t.Cloud.Compute().Networks().Insert(t.Cloud.Project(), network)
+
+		op, err := t.Cloud.Compute().Networks().Insert(t.Cloud.Project(), network)
 		if err != nil {
 			return fmt.Errorf("error creating Network: %v", err)
 		}
+		if err := t.Cloud.WaitForOp(op); err != nil {
+			return fmt.Errorf("error waiting for Network creation to complete: %w", err)
+		}
 	} else {
 		if a.Mode == "legacy" {
 			return fmt.Errorf("GCE networks in legacy mode are not supported.  Please convert to auto mode or specify a different network.")
@@ -157,12 +187,18 @@ func (_ *Network) RenderGCE(t *gce.GCEAPITarget, a, e, changes *Network) error {
 }
 
 type terraformNetwork struct {
-	Name                  *string `json:"name" cty:"name"`
-	IPv4Range             *string `json:"ipv4_range,omitempty" cty:"ipv4_range"`
-	AutoCreateSubnetworks *bool   `json:"auto_create_subnetworks,omitempty" cty:"auto_create_subnetworks"`
+	Name                  *string `cty:"name"`
+	IPv4Range             *string `cty:"ipv4_range"`
+	AutoCreateSubnetworks *bool   `cty:"auto_create_subnetworks"`
 }
 
 func (_ *Network) RenderTerraform(t *terraform.TerraformTarget, a, e, changes *Network) error {
+	shared := fi.BoolValue(e.Shared)
+	if shared {
+		// Not terraform owned / managed
+		return nil
+	}
+
 	tf := &terraformNetwork{
 		Name: e.Name,
 	}
@@ -181,6 +217,16 @@ func (_ *Network) RenderTerraform(t *terraform.TerraformTarget, a, e, changes *N
 	return t.RenderResource("google_compute_network", *e.Name, tf)
 }
 
-func (i *Network) TerraformName() *terraformWriter.Literal {
-	return terraformWriter.LiteralProperty("google_compute_network", *i.Name, "name")
+func (e *Network) TerraformLink() *terraformWriter.Literal {
+	shared := fi.BoolValue(e.Shared)
+	if shared {
+		if e.Name == nil {
+			klog.Fatalf("Name must be set, if network is shared: %#v", e)
+		}
+
+		klog.V(4).Infof("reusing existing network with name %q", *e.Name)
+		return terraformWriter.LiteralFromStringValue(*e.Name)
+	}
+
+	return terraformWriter.LiteralProperty("google_compute_network", *e.Name, "name")
 }
