@@ -74,9 +74,6 @@ const (
 	ResourceTypeSubnet       = "subnets"
 )
 
-// ErrNotFound is used to inform that the object is not found
-var ErrNotFound = "Resource not found"
-
 // readBackoff is the backoff strategy for openstack read retries.
 var readBackoff = wait.Backoff{
 	Duration: time.Second,
@@ -268,6 +265,7 @@ type OpenstackCloud interface {
 	ListAvailabilityZones(serviceClient *gophercloud.ServiceClient) ([]az.AvailabilityZone, error)
 	AssociateToPool(server *servers.Server, poolID string, opts v2pools.CreateMemberOpts) (*v2pools.Member, error)
 	CreatePool(opts v2pools.CreateOpts) (*v2pools.Pool, error)
+	CreatePoolMonitor(opts monitors.CreateOpts) (*monitors.Monitor, error)
 	GetPool(poolID string, memberID string) (*v2pools.Member, error)
 	ListPools(v2pools.ListOpts) ([]v2pools.Pool, error)
 
@@ -773,6 +771,10 @@ func isNotFound(err error) bool {
 		return true
 	}
 
+	if _, ok := err.(gophercloud.ErrResourceNotFound); ok {
+		return true
+	}
+
 	if errCode, ok := err.(gophercloud.ErrUnexpectedResponseCode); ok {
 		if errCode.Actual == http.StatusNotFound {
 			return true
