@@ -31,6 +31,7 @@ import (
 	"encoding/base64"
 	"encoding/json"
 	"fmt"
+	"net"
 	"os"
 	"path"
 	"sort"
@@ -48,12 +49,17 @@ import (
 	"k8s.io/kops/pkg/apis/kops/util"
 	"k8s.io/kops/pkg/dns"
 	"k8s.io/kops/pkg/featureflag"
+	"k8s.io/kops/pkg/flagbuilder"
+	"k8s.io/kops/pkg/kubemanifest"
 	"k8s.io/kops/pkg/model"
+	"k8s.io/kops/pkg/model/components/kopscontroller"
+	"k8s.io/kops/pkg/model/iam"
 	"k8s.io/kops/pkg/resources/spotinst"
 	"k8s.io/kops/pkg/wellknownports"
 	"k8s.io/kops/upup/pkg/fi"
 	"k8s.io/kops/upup/pkg/fi/cloudup/awsup"
 	"k8s.io/kops/upup/pkg/fi/cloudup/gce"
+	gcetpm "k8s.io/kops/upup/pkg/fi/cloudup/gce/tpm"
 	"k8s.io/kops/util/pkg/env"
 	"sigs.k8s.io/yaml"
 )
@@ -71,12 +77,12 @@ type TemplateFunctions struct {
 func (tf *TemplateFunctions) AddTo(dest template.FuncMap, secretStore fi.SecretStore) (err error) {
 	cluster := tf.Cluster
 
-	dest["EtcdScheme"] = tf.EtcdScheme
-	dest["SharedVPC"] = tf.SharedVPC
 	dest["ToJSON"] = tf.ToJSON
 	dest["ToYAML"] = tf.ToYAML
+	dest["KubeObjectToApplyYAML"] = kubemanifest.KubeObjectToApplyYAML
+
+	dest["SharedVPC"] = tf.SharedVPC
 	dest["UseBootstrapTokens"] = tf.UseBootstrapTokens
-	dest["UseEtcdTLS"] = tf.UseEtcdTLS
 	// Remember that we may be on a different arch from the target.  Hard-code for now.
 	dest["replace"] = func(s, find, replace string) string {
 		return strings.Replace(s, find, replace, -1)
@@ -84,10 +90,14 @@ func (tf *TemplateFunctions) AddTo(dest template.FuncMap, secretStore fi.SecretS
 	dest["join"] = func(a []string, sep string) string {
 		return strings.Join(a, sep)
 	}
+	dest["joinHostPort"] = net.JoinHostPort
 
 	sprigTxtFuncMap := sprig.TxtFuncMap()
+	dest["nindent"] = sprigTxtFuncMap["nindent"]
 	dest["indent"] = sprigTxtFuncMap["indent"]
 	dest["contains"] = sprigTxtFuncMap["contains"]
+	dest["trimPrefix"] = sprigTxtFuncMap["trimPrefix"]
+	dest["semverCompare"] = sprigTxtFuncMap["semverCompare"]
 
 	dest["ClusterName"] = tf.ClusterName
 	dest["WithDefaultBool"] = func(v *bool, defaultValue bool) bool {
@@ -108,6 +118,16 @@ func (tf *TemplateFunctions) AddTo(dest template.FuncMap, secretStore fi.SecretS
 		return cluster.Spec.KubeDNS
 	}
 
+	dest["GossipDomains"] = func() []string {
+		var names []string
+
+		if dns.IsGossipHostname(cluster.Spec.MasterInternalName) {
+			names = append(names, "k8s.local")
+		}
+
+		return names
+	}
+
 	dest["NodeLocalDNSClusterIP"] = func() string {
 		if cluster.Spec.KubeProxy.ProxyMode == "ipvs" {
 			return cluster.Spec.KubeDNS.ServerIP
@@ -120,6 +140,7 @@ func (tf *TemplateFunctions) AddTo(dest template.FuncMap, secretStore fi.SecretS
 
 	dest["KopsControllerArgv"] = tf.KopsControllerArgv
 	dest["KopsControllerConfig"] = tf.KopsControllerConfig
+	kopscontroller.AddTemplateFunctions(cluster, dest)
 	dest["DnsControllerArgv"] = tf.DNSControllerArgv
 	dest["ExternalDnsArgv"] = tf.ExternalDNSArgv
 	dest["CloudControllerConfigArgv"] = tf.CloudControllerConfigArgv
@@ -131,6 +152,7 @@ func (tf *TemplateFunctions) AddTo(dest template.FuncMap, secretStore fi.SecretS
 
 	// will return openstack external ccm image location for current kubernetes version
 	dest["OpenStackCCMTag"] = tf.OpenStackCCMTag
+	dest["OpenStackCSITag"] = tf.OpenStackCSITag
 	dest["ProxyEnv"] = tf.ProxyEnv
 
 	dest["KopsSystemEnv"] = tf.KopsSystemEnv
@@ -160,6 +182,12 @@ func (tf *TemplateFunctions) AddTo(dest template.FuncMap, secretStore fi.SecretS
 			for _, e := range c.Env {
 				envVars[e.Name] = e.Value
 			}
+			envVars["ENABLE_IPv4"] = strconv.FormatBool(!cluster.Spec.IsIPv6Only())
+			envVars["ENABLE_IPv6"] = strconv.FormatBool(cluster.Spec.IsIPv6Only())
+			if cluster.Spec.IsIPv6Only() {
+				envVars["ENABLE_PREFIX_DELEGATION"] = "true"
+				envVars["WARM_PREFIX_TARGET"] = "1"
+			}
 			return envVars
 		}
 	}
@@ -257,6 +285,8 @@ func (tf *TemplateFunctions) AddTo(dest template.FuncMap, secretStore fi.SecretS
 
 	dest["ParseTaint"] = util.ParseTaint
 
+	dest["PodIdentityWebhookConfigMapData"] = tf.podIdentityWebhookConfigMapData
+
 	return nil
 }
 
@@ -280,15 +310,6 @@ func (tf *TemplateFunctions) ToYAML(data interface{}) string {
 	return string(encoded)
 }
 
-// EtcdScheme parses and grabs the protocol to the etcd cluster
-func (tf *TemplateFunctions) EtcdScheme() string {
-	if tf.UseEtcdTLS() {
-		return "https"
-	}
-
-	return "http"
-}
-
 // SharedVPC is a simple helper function which makes the templates for a shared VPC clearer
 func (tf *TemplateFunctions) SharedVPC() bool {
 	return tf.Cluster.SharedVPC()
@@ -305,7 +326,12 @@ func (tf *TemplateFunctions) GetInstanceGroup(name string) (*kops.InstanceGroup,
 
 // ControlPlaneControllerReplicas returns the amount of replicas for a controllers that should run in the cluster
 // If the cluster has a highly available control plane, this function will return 2, if it has 1 control plane node, it will return 1
-func (tf *TemplateFunctions) ControlPlaneControllerReplicas() int {
+// deployOnWorkersIfExternalPermissons should be true if a controller runs on worker nodes when external IAM permissions is enabled for the cluster.
+// In this case it is assumed that it can run 2 replicas.
+func (tf *TemplateFunctions) ControlPlaneControllerReplicas(deployOnWorkersIfExternalPermissons bool) int {
+	if deployOnWorkersIfExternalPermissons && fi.BoolValue(tf.Cluster.Spec.IAM.UseServiceAccountExternalPermissions) {
+		return 2
+	}
 	if tf.HasHighlyAvailableControlPlane() {
 		return 2
 	}
@@ -340,41 +366,28 @@ func (tf *TemplateFunctions) CloudControllerConfigArgv() ([]string, error) {
 	if cluster.Spec.ExternalCloudControllerManager == nil {
 		return nil, fmt.Errorf("ExternalCloudControllerManager is nil")
 	}
-	var argv []string
 
-	if cluster.Spec.ExternalCloudControllerManager.Master != "" {
-		argv = append(argv, fmt.Sprintf("--master=%s", cluster.Spec.ExternalCloudControllerManager.Master))
+	argv, err := flagbuilder.BuildFlagsList(cluster.Spec.ExternalCloudControllerManager)
+	if err != nil {
+		return nil, err
 	}
-	if cluster.Spec.ExternalCloudControllerManager.LogLevel != 0 {
-		argv = append(argv, fmt.Sprintf("--v=%d", cluster.Spec.ExternalCloudControllerManager.LogLevel))
-	} else {
+
+	// default verbosity to 2
+	if cluster.Spec.ExternalCloudControllerManager.LogLevel == 0 {
 		argv = append(argv, "--v=2")
 	}
-	if cluster.Spec.ExternalCloudControllerManager.CloudProvider != "" {
-		argv = append(argv, fmt.Sprintf("--cloud-provider=%s", cluster.Spec.ExternalCloudControllerManager.CloudProvider))
-	} else if cluster.Spec.CloudProvider != "" {
-		argv = append(argv, fmt.Sprintf("--cloud-provider=%s", cluster.Spec.CloudProvider))
-	} else {
-		return nil, fmt.Errorf("Cloud Provider is not set")
+
+	// take the cloud provider value from clusterSpec if unset
+	if cluster.Spec.ExternalCloudControllerManager.CloudProvider == "" {
+		if cluster.Spec.CloudProvider != "" {
+			argv = append(argv, fmt.Sprintf("--cloud-provider=%s", cluster.Spec.CloudProvider))
+		} else {
+			return nil, fmt.Errorf("Cloud Provider is not set")
+		}
 	}
-	if cluster.Spec.ExternalCloudControllerManager.ClusterName != "" {
-		argv = append(argv, fmt.Sprintf("--cluster-name=%s", cluster.Spec.ExternalCloudControllerManager.ClusterName))
-	}
-	if cluster.Spec.ExternalCloudControllerManager.ClusterCIDR != "" {
-		argv = append(argv, fmt.Sprintf("--cluster-cidr=%s", cluster.Spec.ExternalCloudControllerManager.ClusterCIDR))
-	}
-	if cluster.Spec.ExternalCloudControllerManager.AllocateNodeCIDRs != nil {
-		argv = append(argv, fmt.Sprintf("--allocate-node-cidrs=%t", *cluster.Spec.ExternalCloudControllerManager.AllocateNodeCIDRs))
-	}
-	if cluster.Spec.ExternalCloudControllerManager.ConfigureCloudRoutes != nil {
-		argv = append(argv, fmt.Sprintf("--configure-cloud-routes=%t", *cluster.Spec.ExternalCloudControllerManager.ConfigureCloudRoutes))
-	}
-	if cluster.Spec.ExternalCloudControllerManager.CIDRAllocatorType != nil && *cluster.Spec.ExternalCloudControllerManager.CIDRAllocatorType != "" {
-		argv = append(argv, fmt.Sprintf("--cidr-allocator-type=%s", *cluster.Spec.ExternalCloudControllerManager.CIDRAllocatorType))
-	}
-	if cluster.Spec.ExternalCloudControllerManager.UseServiceAccountCredentials != nil {
-		argv = append(argv, fmt.Sprintf("--use-service-account-credentials=%t", *cluster.Spec.ExternalCloudControllerManager.UseServiceAccountCredentials))
-	} else {
+
+	// default use-service-account-credentials to true
+	if cluster.Spec.ExternalCloudControllerManager.UseServiceAccountCredentials == nil {
 		argv = append(argv, fmt.Sprintf("--use-service-account-credentials=%t", true))
 	}
 
@@ -487,6 +500,13 @@ func (tf *TemplateFunctions) DNSControllerArgv() ([]string, error) {
 			argv = append(argv, "--zone=*/"+zone)
 		}
 	}
+
+	if cluster.Spec.IsIPv6Only() {
+		argv = append(argv, "--internal-ipv6")
+	} else {
+		argv = append(argv, "--internal-ipv4")
+	}
+
 	// permit wildcard updates
 	argv = append(argv, "--zone=*/*")
 	// Verbose, but not crazy logging
@@ -563,11 +583,35 @@ func (tf *TemplateFunctions) KopsControllerConfig() (string, error) {
 				NodesRoles: nodesRoles.List(),
 				Region:     tf.Region,
 			}
+
+			if cluster.Spec.ExternalCloudControllerManager != nil && cluster.IsKubernetesGTE("1.22") {
+				config.Server.UseInstanceIDForNodeName = true
+			}
+
+		case kops.CloudProviderGCE:
+			c := tf.cloud.(gce.GCECloud)
+
+			config.Server.Provider.GCE = &gcetpm.TPMVerifierOptions{
+				ProjectID:   c.Project(),
+				ClusterName: tf.ClusterName(),
+				Region:      tf.Region,
+				MaxTimeSkew: 300,
+			}
 		default:
 			return "", fmt.Errorf("unsupported cloud provider %s", cluster.Spec.CloudProvider)
 		}
 	}
 
+	if cluster.Spec.IsKopsControllerIPAM() {
+		config.EnableCloudIPAM = true
+	}
+
+	if dns.IsGossipHostname(cluster.Spec.MasterInternalName) {
+		config.Discovery = &kopscontrollerconfig.DiscoveryOptions{
+			Enabled: true,
+		}
+	}
+
 	// To avoid indentation problems, we marshal as json.  json is a subset of yaml
 	b, err := json.Marshal(config)
 	if err != nil {
@@ -611,7 +655,7 @@ func (tf *TemplateFunctions) ExternalDNSArgv() ([]string, error) {
 	}
 
 	argv = append(argv, "--events")
-	if fi.BoolValue(externalDNS.WatchIngress) {
+	if externalDNS.WatchIngress == nil || *externalDNS.WatchIngress {
 		argv = append(argv, "--source=ingress")
 	}
 	argv = append(argv, "--source=pod")
@@ -672,6 +716,9 @@ func (tf *TemplateFunctions) OpenStackCCMTag() string {
 		if parsed.Minor == 13 {
 			// The bugfix release
 			tag = "1.13.1"
+		} else if parsed.Minor == 23 {
+			// The bugfix release, see https://github.com/kubernetes/cloud-provider-openstack/releases
+			tag = "v1.23.1"
 		} else {
 			// otherwise we use always .0 ccm image, if needed that can be overrided using clusterspec
 			tag = fmt.Sprintf("v%d.%d.0", parsed.Major, parsed.Minor)
@@ -680,6 +727,20 @@ func (tf *TemplateFunctions) OpenStackCCMTag() string {
 	return tag
 }
 
+// OpenStackCSI returns OpenStack csi current image
+// with tag specified to k8s version
+func (tf *TemplateFunctions) OpenStackCSITag() string {
+	var tag string
+	parsed, err := util.ParseKubernetesVersion(tf.Cluster.Spec.KubernetesVersion)
+	if err != nil {
+		tag = "latest"
+	} else {
+		// otherwise we use always .0 csi image, if needed that can be overrided using cloud config spec
+		tag = fmt.Sprintf("v%d.%d.0", parsed.Major, parsed.Minor)
+	}
+	return tag
+}
+
 // GetNodeInstanceGroups returns a map containing the defined instance groups of role "Node".
 func (tf *TemplateFunctions) GetNodeInstanceGroups() map[string]kops.InstanceGroupSpec {
 	nodegroups := make(map[string]kops.InstanceGroupSpec)
@@ -690,3 +751,28 @@ func (tf *TemplateFunctions) GetNodeInstanceGroups() map[string]kops.InstanceGro
 	}
 	return nodegroups
 }
+
+type podIdentityWebhookMapping struct {
+	RoleARN         string
+	Audience        string
+	UseRegionalSTS  bool
+	TokenExpiration int64
+}
+
+func (tf *TemplateFunctions) podIdentityWebhookConfigMapData() (string, error) {
+	sas := tf.Cluster.Spec.IAM.ServiceAccountExternalPermissions
+	mappings := make(map[string]podIdentityWebhookMapping)
+	for _, sa := range sas {
+		if sa.AWS == nil {
+			continue
+		}
+		key := sa.Namespace + "/" + sa.Name
+		mappings[key] = podIdentityWebhookMapping{
+			RoleARN:        fmt.Sprintf("arn:%s:iam::%s:role/%s", tf.AWSPartition, tf.AWSAccountID, iam.IAMNameForServiceAccountRole(sa.Name, sa.Namespace, tf.ClusterName())),
+			Audience:       "amazonaws.com",
+			UseRegionalSTS: true,
+		}
+	}
+	jsonBytes, err := json.Marshal(mappings)
+	return fmt.Sprintf("%q", jsonBytes), err
+}
