@@ -23,7 +23,6 @@ import (
 	"errors"
 	"fmt"
 	"io"
-	"io/ioutil"
 	"net"
 	"net/url"
 	"os"
@@ -33,16 +32,22 @@ import (
 	"time"
 
 	"github.com/aws/aws-sdk-go/service/kms"
+
 	"k8s.io/kops/nodeup/pkg/model"
+	"k8s.io/kops/nodeup/pkg/model/dns"
 	"k8s.io/kops/nodeup/pkg/model/networking"
 	api "k8s.io/kops/pkg/apis/kops"
 	"k8s.io/kops/pkg/apis/kops/registry"
 	"k8s.io/kops/pkg/apis/nodeup"
 	"k8s.io/kops/pkg/assets"
+	"k8s.io/kops/pkg/bootstrap"
 	"k8s.io/kops/pkg/configserver"
 	"k8s.io/kops/pkg/kopscodecs"
+	"k8s.io/kops/pkg/resolver"
 	"k8s.io/kops/upup/pkg/fi"
 	"k8s.io/kops/upup/pkg/fi/cloudup/awsup"
+	"k8s.io/kops/upup/pkg/fi/cloudup/gce/gcediscovery"
+	"k8s.io/kops/upup/pkg/fi/cloudup/gce/tpm/gcetpmsigner"
 	"k8s.io/kops/upup/pkg/fi/nodeup/cloudinit"
 	"k8s.io/kops/upup/pkg/fi/nodeup/local"
 	"k8s.io/kops/upup/pkg/fi/nodeup/nodetasks"
@@ -56,7 +61,6 @@ import (
 	"github.com/aws/aws-sdk-go/aws/ec2metadata"
 	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/autoscaling"
-	"github.com/aws/aws-sdk-go/service/ec2"
 	"k8s.io/klog/v2"
 )
 
@@ -110,7 +114,7 @@ func (c *NodeUpCommand) Run(out io.Writer) error {
 	if bootConfig.ConfigServer != nil {
 		response, err := getNodeConfigFromServer(ctx, &bootConfig, region)
 		if err != nil {
-			return err
+			return fmt.Errorf("failed to get node config from server: %w", err)
 		}
 		nodeConfig = response.NodeConfig
 	} else if fi.StringValue(bootConfig.ConfigBase) != "" {
@@ -299,6 +303,7 @@ func (c *NodeUpCommand) Run(out io.Writer) error {
 	}
 
 	loader := &Loader{}
+	loader.Builders = append(loader.Builders, &dns.GossipBuilder{NodeupModelContext: modelContext})
 	loader.Builders = append(loader.Builders, &model.NTPBuilder{NodeupModelContext: modelContext})
 	loader.Builders = append(loader.Builders, &model.MiscUtilsBuilder{NodeupModelContext: modelContext})
 	loader.Builders = append(loader.Builders, &model.DirectoryBuilder{NodeupModelContext: modelContext})
@@ -312,7 +317,6 @@ func (c *NodeUpCommand) Run(out io.Writer) error {
 	loader.Builders = append(loader.Builders, &model.HookBuilder{NodeupModelContext: modelContext})
 	loader.Builders = append(loader.Builders, &model.KubeletBuilder{NodeupModelContext: modelContext})
 	loader.Builders = append(loader.Builders, &model.KubectlBuilder{NodeupModelContext: modelContext})
-	loader.Builders = append(loader.Builders, &model.EtcdBuilder{NodeupModelContext: modelContext})
 	loader.Builders = append(loader.Builders, &model.LogrotateBuilder{NodeupModelContext: modelContext})
 	loader.Builders = append(loader.Builders, &model.ManifestsBuilder{NodeupModelContext: modelContext})
 	loader.Builders = append(loader.Builders, &model.PackagesBuilder{NodeupModelContext: modelContext})
@@ -327,12 +331,12 @@ func (c *NodeUpCommand) Run(out io.Writer) error {
 	loader.Builders = append(loader.Builders, &model.KubeProxyBuilder{NodeupModelContext: modelContext})
 	loader.Builders = append(loader.Builders, &model.KopsControllerBuilder{NodeupModelContext: modelContext})
 	loader.Builders = append(loader.Builders, &model.WarmPoolBuilder{NodeupModelContext: modelContext})
+	loader.Builders = append(loader.Builders, &model.PrefixBuilder{NodeupModelContext: modelContext})
 
 	loader.Builders = append(loader.Builders, &networking.CommonBuilder{NodeupModelContext: modelContext})
 	loader.Builders = append(loader.Builders, &networking.CalicoBuilder{NodeupModelContext: modelContext})
 	loader.Builders = append(loader.Builders, &networking.CiliumBuilder{NodeupModelContext: modelContext})
 	loader.Builders = append(loader.Builders, &networking.KuberouterBuilder{NodeupModelContext: modelContext})
-	loader.Builders = append(loader.Builders, &networking.LyftVPCBuilder{NodeupModelContext: modelContext})
 
 	loader.Builders = append(loader.Builders, &model.BootstrapClientBuilder{NodeupModelContext: modelContext})
 	taskMap, err := loader.Build()
@@ -355,7 +359,10 @@ func (c *NodeUpCommand) Run(out io.Writer) error {
 	switch c.Target {
 	case "direct":
 		target = &local.LocalTarget{
-			CacheDir: c.CacheDir,
+			CacheDir:   c.CacheDir,
+			Cloud:      cloud,
+			InstanceID: modelContext.InstanceID,
+			Cluster:    c.cluster,
 		}
 	case "dryrun":
 		assetBuilder := assets.NewAssetBuilder(c.cluster, false)
@@ -415,7 +422,7 @@ func getMachineType() (string, error) {
 func completeWarmingLifecycleAction(cloud awsup.AWSCloud, modelContext *model.NodeupModelContext) error {
 	asgName := modelContext.BootConfig.InstanceGroupName + "." + modelContext.Cluster.GetName()
 	hookName := "kops-warmpool"
-	svc := cloud.(awsup.AWSCloud).Autoscaling()
+	svc := cloud.Autoscaling()
 	hooks, err := svc.DescribeLifecycleHooks(&autoscaling.DescribeLifecycleHooksInput{
 		AutoScalingGroupName: &asgName,
 		LifecycleHookNames:   []*string{&hookName},
@@ -443,35 +450,27 @@ func completeWarmingLifecycleAction(cloud awsup.AWSCloud, modelContext *model.No
 }
 
 func evaluateSpec(c *NodeUpCommand, nodeupConfig *nodeup.Config) error {
-	var err error
-
-	c.cluster.Spec.Kubelet.HostnameOverride, err = evaluateHostnameOverride(c.cluster.Spec.Kubelet.HostnameOverride)
+	hostnameOverride, err := evaluateHostnameOverride(api.CloudProviderID(c.cluster.Spec.CloudProvider), nodeupConfig.UseInstanceIDForNodeName)
 	if err != nil {
 		return err
 	}
 
-	c.cluster.Spec.MasterKubelet.HostnameOverride, err = evaluateHostnameOverride(c.cluster.Spec.MasterKubelet.HostnameOverride)
+	c.cluster.Spec.Kubelet.HostnameOverride = hostnameOverride
+	c.cluster.Spec.MasterKubelet.HostnameOverride = hostnameOverride
+
+	nodeupConfig.KubeletConfig.HostnameOverride = hostnameOverride
+
+	if c.cluster.Spec.KubeProxy == nil {
+		c.cluster.Spec.KubeProxy = &api.KubeProxyConfig{}
+	}
+
+	c.cluster.Spec.KubeProxy.HostnameOverride = hostnameOverride
+	c.cluster.Spec.KubeProxy.BindAddress, err = evaluateBindAddress(c.cluster.Spec.KubeProxy.BindAddress)
 	if err != nil {
 		return err
 	}
 
-	nodeupConfig.KubeletConfig.HostnameOverride, err = evaluateHostnameOverride(nodeupConfig.KubeletConfig.HostnameOverride)
-	if err != nil {
-		return err
-	}
-
-	if c.cluster.Spec.KubeProxy != nil {
-		c.cluster.Spec.KubeProxy.HostnameOverride, err = evaluateHostnameOverride(c.cluster.Spec.KubeProxy.HostnameOverride)
-		if err != nil {
-			return err
-		}
-		c.cluster.Spec.KubeProxy.BindAddress, err = evaluateBindAddress(c.cluster.Spec.KubeProxy.BindAddress)
-		if err != nil {
-			return err
-		}
-	}
-
-	if c.cluster.Spec.Docker != nil {
+	if c.cluster.Spec.ContainerRuntime == "docker" {
 		err = evaluateDockerSpecStorage(c.cluster.Spec.Docker)
 		if err != nil {
 			return err
@@ -481,55 +480,20 @@ func evaluateSpec(c *NodeUpCommand, nodeupConfig *nodeup.Config) error {
 	return nil
 }
 
-func evaluateHostnameOverride(hostnameOverride string) (string, error) {
-	if hostnameOverride == "" || hostnameOverride == "@hostname" {
-		return "", nil
-	}
-	k := strings.TrimSpace(hostnameOverride)
-	k = strings.ToLower(k)
-
-	if k == "@aws" {
-		// We recognize @aws as meaning "the private DNS name from AWS", to generate this we need to get a few pieces of information
-		azBytes, err := vfs.Context.ReadFile("metadata://aws/meta-data/placement/availability-zone")
+func evaluateHostnameOverride(cloudProvider api.CloudProviderID, useInstanceIDForNodeName bool) (string, error) {
+	switch cloudProvider {
+	case api.CloudProviderAWS:
+		source := "local-hostname"
+		if useInstanceIDForNodeName {
+			source = "instance-id"
+		}
+		nodeNameBytes, err := vfs.Context.ReadFile("metadata://aws/meta-data/" + source)
 		if err != nil {
-			return "", fmt.Errorf("error reading availability zone from AWS metadata: %v", err)
+			return "", fmt.Errorf("error reading %s from AWS metadata: %v", source, err)
 		}
+		return string(nodeNameBytes), nil
 
-		instanceIDBytes, err := vfs.Context.ReadFile("metadata://aws/meta-data/instance-id")
-		if err != nil {
-			return "", fmt.Errorf("error reading instance-id from AWS metadata: %v", err)
-		}
-		instanceID := string(instanceIDBytes)
-
-		config := aws.NewConfig()
-		config = config.WithCredentialsChainVerboseErrors(true)
-
-		s, err := session.NewSession(config)
-		if err != nil {
-			return "", fmt.Errorf("error starting new AWS session: %v", err)
-		}
-
-		svc := ec2.New(s, config.WithRegion(string(azBytes[:len(azBytes)-1])))
-
-		result, err := svc.DescribeInstances(&ec2.DescribeInstancesInput{
-			InstanceIds: []*string{&instanceID},
-		})
-		if err != nil {
-			return "", fmt.Errorf("error describing instances: %v", err)
-		}
-
-		if len(result.Reservations) != 1 {
-			return "", fmt.Errorf("Too many reservations returned for the single instance-id")
-		}
-
-		if len(result.Reservations[0].Instances) != 1 {
-			return "", fmt.Errorf("Too many instances returned for the single instance-id")
-		}
-		return *(result.Reservations[0].Instances[0].PrivateDnsName), nil
-	}
-
-	if k == "@gce" {
-		// We recognize @gce as meaning the hostname from the GCE metadata service
+	case api.CloudProviderGCE:
 		// This lets us tolerate broken hostnames (i.e. systemd)
 		b, err := vfs.Context.ReadFile("metadata://gce/instance/hostname")
 		if err != nil {
@@ -541,10 +505,7 @@ func evaluateHostnameOverride(hostnameOverride string) (string, error) {
 		fullyQualified := string(b)
 		bareHostname := strings.Split(fullyQualified, ".")[0]
 		return bareHostname, nil
-	}
-
-	if k == "@digitalocean" {
-		// @digitalocean means to use the private ipv4 address of a droplet as the hostname override
+	case api.CloudProviderDO:
 		vBytes, err := vfs.Context.ReadFile("metadata://digitalocean/interfaces/private/0/ipv4/address")
 		if err != nil {
 			return "", fmt.Errorf("error reading droplet private IP from DigitalOcean metadata: %v", err)
@@ -556,10 +517,7 @@ func evaluateHostnameOverride(hostnameOverride string) (string, error) {
 		}
 
 		return hostname, nil
-	}
-
-	if k == "@alicloud" {
-		// @alicloud means to use the "{az}.{instance-id}" of a instance as the hostname override
+	case api.CloudProviderALI:
 		azBytes, err := vfs.Context.ReadFile("metadata://alicloud/zone-id")
 		if err != nil {
 			return "", fmt.Errorf("error reading zone-id from Alicloud metadata: %v", err)
@@ -575,7 +533,7 @@ func evaluateHostnameOverride(hostnameOverride string) (string, error) {
 		return fmt.Sprintf("%s.%s", az, instanceID), nil
 	}
 
-	return hostnameOverride, nil
+	return "", nil
 }
 
 func evaluateBindAddress(bindAddress string) (string, error) {
@@ -660,7 +618,7 @@ func evaluateDockerSpecStorage(spec *api.DockerConfig) error {
 
 // kernelHasFilesystem checks if /proc/filesystems contains the specified filesystem
 func kernelHasFilesystem(fs string) (bool, error) {
-	contents, err := ioutil.ReadFile("/proc/filesystems")
+	contents, err := os.ReadFile("/proc/filesystems")
 	if err != nil {
 		return false, fmt.Errorf("error reading /proc/filesystems: %v", err)
 	}
@@ -754,7 +712,8 @@ func seedRNG(ctx context.Context, bootConfig *nodeup.BootConfig, region string)
 
 // getNodeConfigFromServer queries kops-controller for our node's configuration.
 func getNodeConfigFromServer(ctx context.Context, bootConfig *nodeup.BootConfig, region string) (*nodeup.BootstrapResponse, error) {
-	var authenticator fi.Authenticator
+	var authenticator bootstrap.Authenticator
+	var resolver resolver.Resolver
 
 	switch api.CloudProviderID(bootConfig.CloudProvider) {
 	case api.CloudProviderAWS:
@@ -763,12 +722,25 @@ func getNodeConfigFromServer(ctx context.Context, bootConfig *nodeup.BootConfig,
 			return nil, err
 		}
 		authenticator = a
+	case api.CloudProviderGCE:
+		a, err := gcetpmsigner.NewTPMAuthenticator()
+		if err != nil {
+			return nil, err
+		}
+		authenticator = a
+
+		discovery, err := gcediscovery.New()
+		if err != nil {
+			return nil, err
+		}
+		resolver = discovery
 	default:
-		return nil, fmt.Errorf("unsupported cloud provider %s", bootConfig.CloudProvider)
+		return nil, fmt.Errorf("unsupported cloud provider for node configuration %s", bootConfig.CloudProvider)
 	}
 
 	client := &nodetasks.KopsBootstrapClient{
 		Authenticator: authenticator,
+		Resolver:      resolver,
 	}
 
 	u, err := url.Parse(bootConfig.ConfigServer.Server)
